pub enum BlockAwareCreditOperation {
SetCredits(Credits),
AddToCreditsOperations(BTreeMap<BlockHeight, Credits>),
}Expand description
An enum for credit operations in compacted address blobs
Variants
SetCredits(Credits)
We are setting credit amounts - the final value after all operations
AddToCreditsOperations(BTreeMap<BlockHeight, Credits>)
We are adding to credits - individual additions by block height
Implementations
Sourceimpl BlockAwareCreditOperation
impl BlockAwareCreditOperation
Sourcepub fn merge(&mut self, block_height: BlockHeight, operation: &CreditOperation)
pub fn merge(&mut self, block_height: BlockHeight, operation: &CreditOperation)
Merges a CreditOperation from a specific block height into this BlockAwareCreditOperation.
The merge logic:
- Once a SetCredits is encountered, the result becomes SetCredits with the final computed value
- If only AddToCredits operations, they are preserved with their block heights
Sourcepub fn from_operation(
block_height: BlockHeight,
operation: &CreditOperation,
) -> Self
pub fn from_operation( block_height: BlockHeight, operation: &CreditOperation, ) -> Self
Creates a new BlockAwareCreditOperation from a CreditOperation at a specific block height.