ExtendedBlockInfoV0Getters

Trait ExtendedBlockInfoV0Getters 

pub trait ExtendedBlockInfoV0Getters {
    // Required methods
    fn basic_info(&self) -> &BlockInfo;
    fn basic_info_mut(&mut self) -> &mut BlockInfo;
    fn basic_info_owned(self) -> BlockInfo;
    fn app_hash(&self) -> &[u8; 32];
    fn quorum_hash(&self) -> &[u8; 32];
    fn proposer_pro_tx_hash(&self) -> &[u8; 32];
    fn block_id_hash(&self) -> &[u8; 32];
    fn signature(&self) -> &[u8; 96];
    fn round(&self) -> u32;
}
Trait for getting values from ExtendedBlockInfoV0

Required Methods

fn basic_info(&self) -> &BlockInfo

Returns a reference to the basic block info.

fn basic_info_mut(&mut self) -> &mut BlockInfo

Returns a mutable reference to the basic block info.

fn basic_info_owned(self) -> BlockInfo

Returns an owned copy of the basic block info.

fn app_hash(&self) -> &[u8; 32]

Returns the app hash.

fn quorum_hash(&self) -> &[u8; 32]

Returns the quorum hash.

fn proposer_pro_tx_hash(&self) -> &[u8; 32]

Proposer pro tx hash.

fn block_id_hash(&self) -> &[u8; 32]

The block id hash

fn signature(&self) -> &[u8; 96]

Returns the signature.

fn round(&self) -> u32

Returns the round.

Implementors