pub struct ContractGroupMembership {
pub contract_group_id: Identifier,
pub member: ContractGroupMember,
}Expand description
A declaration that a part of the created contract joins a contract group.
Fields
contract_group_id: IdentifierThe group joined. Either a group registered earlier by an owner, or the group registered by this same create transition.
member: ContractGroupMemberThe part of the created contract that joins.