pub struct DashPlatformProtocol {
pub protocol_version: u32,
pub identities: IdentityFacade,
pub state_transition: StateTransitionFactory,
}Fields
protocol_version: u32Version of protocol
identities: IdentityFacadePublic facing facades to interact with the library
state_transition: StateTransitionFactoryImplementations
Sourceimpl DashPlatformProtocol
DashPlatformProtocol is the main interface of the library used to perform validation
and creating of different data structures
impl DashPlatformProtocol
DashPlatformProtocol is the main interface of the library used to perform validation and creating of different data structures
pub fn new(protocol_version: u32) -> Self
pub fn identities(&self) -> &IdentityFacade
pub fn state_transition(&self) -> &StateTransitionFactory