DataContractV0Getters

Trait DataContractV0Getters 

pub trait DataContractV0Getters {
Show 16 methods // Required methods fn id(&self) -> Identifier; fn id_ref(&self) -> &Identifier; fn system_version_type(&self) -> u16; fn version(&self) -> u32; fn owner_id(&self) -> Identifier; fn document_type_cloned_for_name( &self, name: &str, ) -> Result<DocumentType, DataContractError>; fn document_type_borrowed_for_name( &self, name: &str, ) -> Result<&DocumentType, DataContractError>; fn document_type_for_name( &self, name: &str, ) -> Result<DocumentTypeRef<'_>, DataContractError>; fn document_type_optional_for_name( &self, name: &str, ) -> Option<DocumentTypeRef<'_>>; fn document_type_cloned_optional_for_name( &self, name: &str, ) -> Option<DocumentType>; fn has_document_type_for_name(&self, name: &str) -> bool; fn document_types_with_contested_indexes( &self, ) -> BTreeMap<&DocumentName, &DocumentType>; fn document_types(&self) -> &BTreeMap<DocumentName, DocumentType>; fn document_types_mut( &mut self, ) -> &mut BTreeMap<DocumentName, DocumentType>; fn config(&self) -> &DataContractConfig; fn config_mut(&mut self) -> &mut DataContractConfig;
}

Required Methods

fn id(&self) -> Identifier

Returns the unique identifier for the data contract.

fn id_ref(&self) -> &Identifier

fn system_version_type(&self) -> u16

fn version(&self) -> u32

Returns the version of this data contract.

fn owner_id(&self) -> Identifier

Returns the identifier of the contract owner.

fn document_type_cloned_for_name( &self, name: &str, ) -> Result<DocumentType, DataContractError>

fn document_type_borrowed_for_name( &self, name: &str, ) -> Result<&DocumentType, DataContractError>

fn document_type_for_name( &self, name: &str, ) -> Result<DocumentTypeRef<'_>, DataContractError>

Returns the document type for the given document name.

fn document_type_optional_for_name( &self, name: &str, ) -> Option<DocumentTypeRef<'_>>

fn document_type_cloned_optional_for_name( &self, name: &str, ) -> Option<DocumentType>

fn has_document_type_for_name(&self, name: &str) -> bool

fn document_types_with_contested_indexes( &self, ) -> BTreeMap<&DocumentName, &DocumentType>

fn document_types(&self) -> &BTreeMap<DocumentName, DocumentType>

Returns a mapping of document names to their corresponding document types.

fn document_types_mut(&mut self) -> &mut BTreeMap<DocumentName, DocumentType>

Returns a mapping of document names to their corresponding document types as mutable.

fn config(&self) -> &DataContractConfig

Returns the internal configuration for the contract.

fn config_mut(&mut self) -> &mut DataContractConfig

Returns the internal configuration for the contract as mutable.

Implementors