DataContractV1Setters

Trait DataContractV1Setters 

pub trait DataContractV1Setters: DataContractV0Setters {
    // Required methods
    fn set_groups(&mut self, groups: BTreeMap<GroupContractPosition, Group>);
    fn set_tokens(
        &mut self,
        tokens: BTreeMap<TokenContractPosition, TokenConfiguration>,
    );
    fn add_group(&mut self, pos: GroupContractPosition, group: Group);
    fn add_token(
        &mut self,
        pos: TokenContractPosition,
        token: TokenConfiguration,
    );
    fn set_created_at(&mut self, created_at: Option<TimestampMillis>);
    fn set_updated_at(&mut self, updated_at: Option<TimestampMillis>);
    fn set_created_at_block_height(&mut self, block_height: Option<BlockHeight>);
    fn set_updated_at_block_height(&mut self, block_height: Option<BlockHeight>);
    fn set_created_at_epoch(&mut self, epoch: Option<EpochIndex>);
    fn set_updated_at_epoch(&mut self, epoch: Option<EpochIndex>);
    fn set_keywords(&mut self, keywords: Vec<String>);
    fn set_description(&mut self, description: Option<String>);
}

Required Methods

fn set_groups(&mut self, groups: BTreeMap<GroupContractPosition, Group>)

Sets the groups map for the data contract.

fn set_tokens( &mut self, tokens: BTreeMap<TokenContractPosition, TokenConfiguration>, )

Sets the tokens map for the data contract.

fn add_group(&mut self, pos: GroupContractPosition, group: Group)

Adds or updates a single group in the groups map.

fn add_token(&mut self, pos: TokenContractPosition, token: TokenConfiguration)

Adds or updates a single token configuration in the tokens map.

fn set_created_at(&mut self, created_at: Option<TimestampMillis>)

Sets the timestamp in milliseconds when the contract was created.

fn set_updated_at(&mut self, updated_at: Option<TimestampMillis>)

Sets the timestamp in milliseconds when the contract was last updated.

fn set_created_at_block_height(&mut self, block_height: Option<BlockHeight>)

Sets the block height at which the contract was created.

fn set_updated_at_block_height(&mut self, block_height: Option<BlockHeight>)

Sets the block height at which the contract was last updated.

fn set_created_at_epoch(&mut self, epoch: Option<EpochIndex>)

Sets the epoch at which the contract was created.

fn set_updated_at_epoch(&mut self, epoch: Option<EpochIndex>)

Sets the block height at which the contract was last updated.

fn set_keywords(&mut self, keywords: Vec<String>)

Sets the keywords for the contract.

fn set_description(&mut self, description: Option<String>)

Sets the description for the contract.

Implementors