pub enum TokenConfiguration {
V0(TokenConfigurationV0),
}Variants
Implementations
Sourceimpl TokenConfiguration
impl TokenConfiguration
Sourcepub fn apply_token_configuration_item(
&mut self,
change_item: TokenConfigurationChangeItem,
)
pub fn apply_token_configuration_item( &mut self, change_item: TokenConfigurationChangeItem, )
Applies a TokenConfigurationChangeItem to this token configuration.
Parameters
change_item: The change item to be applied.
This method modifies the current TokenConfigurationV0 instance in place.
Sourceimpl TokenConfiguration
impl TokenConfiguration
Sourcepub fn can_apply_token_configuration_item(
&self,
change_item: &TokenConfigurationChangeItem,
contract_owner_id: &Identifier,
main_group: Option<GroupContractPosition>,
groups: &BTreeMap<GroupContractPosition, Group>,
action_taker: &ActionTaker,
goal: ActionGoal,
) -> bool
pub fn can_apply_token_configuration_item( &self, change_item: &TokenConfigurationChangeItem, contract_owner_id: &Identifier, main_group: Option<GroupContractPosition>, groups: &BTreeMap<GroupContractPosition, Group>, action_taker: &ActionTaker, goal: ActionGoal, ) -> bool
Applies a TokenConfigurationChangeItem to this token configuration.
Parameters
change_item: The change item to be applied.
This method modifies the current TokenConfigurationV0 instance in place.
Sourceimpl TokenConfiguration
impl TokenConfiguration
Sourcepub fn validate_token_config_groups_exist(
&self,
groups: &BTreeMap<GroupContractPosition, Group>,
platform_version: &PlatformVersion,
) -> Result<SimpleConsensusValidationResult, ProtocolError>
pub fn validate_token_config_groups_exist( &self, groups: &BTreeMap<GroupContractPosition, Group>, platform_version: &PlatformVersion, ) -> Result<SimpleConsensusValidationResult, ProtocolError>
Validates that all group positions referenced in the token configuration exist in the provided groups map.
Parameters
groups: A reference to aBTreeMapcontaining group positions as keys and their associatedGroupobjects as values. These represent the groups defined in the data contract.platform_version: A reference to thePlatformVersionobject specifying the version of the function to call.
Returns
Ok(SimpleConsensusValidationResult): If the validation is successful, returns a result containing a validation result object, which will be empty if no errors are found.Err(ProtocolError): If an unknown or unsupported platform version is specified, an error indicating a version mismatch is returned.
Errors
- If a group position referenced in the token configuration does not exist in the provided
groupsmap, the method will invoke the version-specific validation logic, which will include any corresponding validation errors.
Versioning
- This function dispatches to version-specific validation logic based on the
platform_version. - Currently supports
validate_token_config_groups_exist_v0for version0.
Sourceimpl TokenConfiguration
impl TokenConfiguration
pub fn validate_token_config_update( &self, new_config: &TokenConfiguration, contract_owner_id: &Identifier, groups: &BTreeMap<GroupContractPosition, Group>, action_taker: &ActionTaker, goal: ActionGoal, platform_version: &PlatformVersion, ) -> Result<SimpleConsensusValidationResult, ProtocolError>
Sourceimpl TokenConfiguration
impl TokenConfiguration
pub fn as_cow_v0(&self) -> Cow<'_, TokenConfigurationV0>