pub enum TokenDistributionInfo {
PreProgrammed(TimestampMillis, Identifier),
Perpetual(RewardDistributionMoment, TokenDistributionResolvedRecipient),
}Expand description
Contains information about a specific token distribution instance.
PreProgrammed(TimestampMillis, Identifier): A scheduled distribution with a timestamp and recipient.Perpetual(RewardDistributionMoment, RewardDistributionMoment, TokenDistributionResolvedRecipient): A perpetual distribution with previous and next distribution moments, along with the resolved recipient.
Variants
PreProgrammed(TimestampMillis, Identifier)
A pre-programmed token distribution set for a specific time. Contains the scheduled timestamp and the recipient’s identifier.
Perpetual(RewardDistributionMoment, TokenDistributionResolvedRecipient)
A perpetual token distribution with moment for distribution. The moment is the beginning of the perpetual distribution cycle Includes the last and next distribution times and the resolved recipient.