pub struct TokenDistributionRulesV0 {
pub perpetual_distribution: Option<TokenPerpetualDistribution>,
pub perpetual_distribution_rules: ChangeControlRules,
pub pre_programmed_distribution: Option<TokenPreProgrammedDistribution>,
pub new_tokens_destination_identity: Option<Identifier>,
pub new_tokens_destination_identity_rules: ChangeControlRules,
pub minting_allow_choosing_destination: bool,
pub minting_allow_choosing_destination_rules: ChangeControlRules,
pub change_direct_purchase_pricing_rules: ChangeControlRules,
}Fields
perpetual_distribution: Option<TokenPerpetualDistribution>perpetual_distribution_rules: ChangeControlRulespre_programmed_distribution: Option<TokenPreProgrammedDistribution>new_tokens_destination_identity: Option<Identifier>new_tokens_destination_identity_rules: ChangeControlRulesminting_allow_choosing_destination: boolminting_allow_choosing_destination_rules: ChangeControlRuleschange_direct_purchase_pricing_rules: ChangeControlRulesTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for TokenDistributionRulesV0
impl<'__de, __Context> BorrowDecode<'__de, __Context> for TokenDistributionRulesV0
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Sourceimpl Clone for TokenDistributionRulesV0
impl Clone for TokenDistributionRulesV0
Sourcefn clone(&self) -> TokenDistributionRulesV0
fn clone(&self) -> TokenDistributionRulesV0
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TokenDistributionRulesV0
impl Debug for TokenDistributionRulesV0
Sourceimpl<__Context> Decode<__Context> for TokenDistributionRulesV0
impl<__Context> Decode<__Context> for TokenDistributionRulesV0
Sourceimpl<'de> Deserialize<'de> for TokenDistributionRulesV0
impl<'de> Deserialize<'de> for TokenDistributionRulesV0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Display for TokenDistributionRulesV0
impl Display for TokenDistributionRulesV0
Sourceimpl Encode for TokenDistributionRulesV0
impl Encode for TokenDistributionRulesV0
Sourceimpl From<TokenDistributionRulesV0> for TokenDistributionRules
impl From<TokenDistributionRulesV0> for TokenDistributionRules
Sourcefn from(value: TokenDistributionRulesV0) -> Self
fn from(value: TokenDistributionRulesV0) -> Self
Sourceimpl PartialEq for TokenDistributionRulesV0
impl PartialEq for TokenDistributionRulesV0
Sourceimpl Serialize for TokenDistributionRulesV0
impl Serialize for TokenDistributionRulesV0
Sourceimpl TokenDistributionRulesV0Getters for TokenDistributionRulesV0
Implementing TokenDistributionRulesV0Getters for TokenDistributionRulesV0
impl TokenDistributionRulesV0Getters for TokenDistributionRulesV0
Implementing TokenDistributionRulesV0Getters for TokenDistributionRulesV0
Sourcefn perpetual_distribution(&self) -> Option<&TokenPerpetualDistribution>
fn perpetual_distribution(&self) -> Option<&TokenPerpetualDistribution>
Returns the perpetual distribution configuration.
Sourcefn perpetual_distribution_mut(
&mut self,
) -> Option<&mut TokenPerpetualDistribution>
fn perpetual_distribution_mut( &mut self, ) -> Option<&mut TokenPerpetualDistribution>
Returns the perpetual distribution configuration (mutable).
Sourcefn perpetual_distribution_rules(&self) -> &ChangeControlRules
fn perpetual_distribution_rules(&self) -> &ChangeControlRules
Returns the perpetual distribution change rules.
Sourcefn perpetual_distribution_rules_mut(&mut self) -> &mut ChangeControlRules
fn perpetual_distribution_rules_mut(&mut self) -> &mut ChangeControlRules
Returns the perpetual distribution change rules (mutable).
Sourcefn pre_programmed_distribution(&self) -> Option<&TokenPreProgrammedDistribution>
fn pre_programmed_distribution(&self) -> Option<&TokenPreProgrammedDistribution>
Returns the pre-programmed distribution configuration.
Sourcefn pre_programmed_distribution_mut(
&mut self,
) -> Option<&mut TokenPreProgrammedDistribution>
fn pre_programmed_distribution_mut( &mut self, ) -> Option<&mut TokenPreProgrammedDistribution>
Returns the pre-programmed distribution configuration (mutable).
Sourcefn new_tokens_destination_identity(&self) -> Option<&Identifier>
fn new_tokens_destination_identity(&self) -> Option<&Identifier>
Returns the new tokens destination identity.
Sourcefn new_tokens_destination_identity_rules(&self) -> &ChangeControlRules
fn new_tokens_destination_identity_rules(&self) -> &ChangeControlRules
Returns the rules for changing the new tokens destination identity.
Sourcefn new_tokens_destination_identity_rules_mut(
&mut self,
) -> &mut ChangeControlRules
fn new_tokens_destination_identity_rules_mut( &mut self, ) -> &mut ChangeControlRules
Returns the rules for changing the new tokens destination identity (mutable).
Sourcefn minting_allow_choosing_destination(&self) -> bool
fn minting_allow_choosing_destination(&self) -> bool
Returns whether minting allows choosing destination.
Sourcefn minting_allow_choosing_destination_rules(&self) -> &ChangeControlRules
fn minting_allow_choosing_destination_rules(&self) -> &ChangeControlRules
Returns the rules for changing the minting allow choosing destination setting.
Sourcefn minting_allow_choosing_destination_rules_mut(
&mut self,
) -> &mut ChangeControlRules
fn minting_allow_choosing_destination_rules_mut( &mut self, ) -> &mut ChangeControlRules
Returns the rules for changing the minting allow choosing destination setting (mutable).
Sourcefn change_direct_purchase_pricing_rules(&self) -> &ChangeControlRules
fn change_direct_purchase_pricing_rules(&self) -> &ChangeControlRules
Sourcefn change_direct_purchase_pricing_rules_mut(
&mut self,
) -> &mut ChangeControlRules
fn change_direct_purchase_pricing_rules_mut( &mut self, ) -> &mut ChangeControlRules
Sourceimpl TokenDistributionRulesV0Setters for TokenDistributionRulesV0
Implementing TokenDistributionRulesV0Setters for TokenDistributionRulesV0
impl TokenDistributionRulesV0Setters for TokenDistributionRulesV0
Implementing TokenDistributionRulesV0Setters for TokenDistributionRulesV0
Sourcefn set_perpetual_distribution(
&mut self,
perpetual_distribution: Option<TokenPerpetualDistribution>,
)
fn set_perpetual_distribution( &mut self, perpetual_distribution: Option<TokenPerpetualDistribution>, )
Sets the perpetual distribution configuration.
Sourcefn set_perpetual_distribution_rules(&mut self, rules: ChangeControlRules)
fn set_perpetual_distribution_rules(&mut self, rules: ChangeControlRules)
Sets the perpetual distribution change rules.
Sourcefn set_pre_programmed_distribution(
&mut self,
pre_programmed_distribution: Option<TokenPreProgrammedDistribution>,
)
fn set_pre_programmed_distribution( &mut self, pre_programmed_distribution: Option<TokenPreProgrammedDistribution>, )
Sets the pre-programmed distribution configuration.
Sourcefn set_new_tokens_destination_identity(&mut self, identity: Option<Identifier>)
fn set_new_tokens_destination_identity(&mut self, identity: Option<Identifier>)
Sets the new tokens destination identity.
Sourcefn set_new_tokens_destination_identity_rules(
&mut self,
rules: ChangeControlRules,
)
fn set_new_tokens_destination_identity_rules( &mut self, rules: ChangeControlRules, )
Sets the rules for changing the new tokens destination identity.
Sourcefn set_minting_allow_choosing_destination(&mut self, allow: bool)
fn set_minting_allow_choosing_destination(&mut self, allow: bool)
Sets whether minting allows choosing destination.
Sourcefn set_minting_allow_choosing_destination_rules(
&mut self,
rules: ChangeControlRules,
)
fn set_minting_allow_choosing_destination_rules( &mut self, rules: ChangeControlRules, )
Sets the rules for changing the minting allow choosing destination setting.
Sourcefn set_change_direct_purchase_pricing_rules(
&mut self,
rules: ChangeControlRules,
)
fn set_change_direct_purchase_pricing_rules( &mut self, rules: ChangeControlRules, )
impl Eq for TokenDistributionRulesV0
impl JsonSafeFields for TokenDistributionRulesV0
impl StructuralPartialEq for TokenDistributionRulesV0