DataContractConfigGettersV0

Trait DataContractConfigGettersV0 

pub trait DataContractConfigGettersV0 {
    // Required methods
    fn can_be_deleted(&self) -> bool;
    fn readonly(&self) -> bool;
    fn keeps_history(&self) -> bool;
    fn documents_keep_history_contract_default(&self) -> bool;
    fn documents_mutable_contract_default(&self) -> bool;
    fn documents_can_be_deleted_contract_default(&self) -> bool;
    fn requires_identity_encryption_bounded_key(
        &self,
    ) -> Option<StorageKeyRequirements>;
    fn requires_identity_decryption_bounded_key(
        &self,
    ) -> Option<StorageKeyRequirements>;
}
Trait representing getters for DataContractConfigV0

Required Methods

fn can_be_deleted(&self) -> bool

Returns whether the contract can be deleted.

fn readonly(&self) -> bool

Returns whether the contract is read-only.

fn keeps_history(&self) -> bool

Returns whether the contract keeps history.

fn documents_keep_history_contract_default(&self) -> bool

Returns whether documents in the contract keep history by default.

fn documents_mutable_contract_default(&self) -> bool

Returns whether documents in the contract are mutable by default.

fn documents_can_be_deleted_contract_default(&self) -> bool

fn requires_identity_encryption_bounded_key( &self, ) -> Option<StorageKeyRequirements>

Encryption key storage requirements

fn requires_identity_decryption_bounded_key( &self, ) -> Option<StorageKeyRequirements>

Decryption key storage requirements

Implementors