DataContractConfigSettersV0

Trait DataContractConfigSettersV0 

pub trait DataContractConfigSettersV0 {
    // Required methods
    fn set_can_be_deleted(&mut self, value: bool);
    fn set_readonly(&mut self, value: bool);
    fn set_keeps_history(&mut self, value: bool);
    fn set_documents_keep_history_contract_default(&mut self, value: bool);
    fn set_documents_mutable_contract_default(&mut self, value: bool);
    fn set_documents_can_be_deleted_contract_default(&mut self, value: bool);
    fn set_requires_identity_encryption_bounded_key(
        &mut self,
        value: Option<StorageKeyRequirements>,
    );
    fn set_requires_identity_decryption_bounded_key(
        &mut self,
        value: Option<StorageKeyRequirements>,
    );
}
Trait representing setters for DataContractConfigV0

Required Methods

fn set_can_be_deleted(&mut self, value: bool)

Sets whether the contract can be deleted.

fn set_readonly(&mut self, value: bool)

Sets whether the contract is read-only.

fn set_keeps_history(&mut self, value: bool)

Sets whether the contract keeps history.

fn set_documents_keep_history_contract_default(&mut self, value: bool)

Sets whether documents in the contract keep history by default.

fn set_documents_mutable_contract_default(&mut self, value: bool)

Sets whether documents in the contract are mutable by default.

fn set_documents_can_be_deleted_contract_default(&mut self, value: bool)

Sets whether documents in the contract can be deleted by default.

fn set_requires_identity_encryption_bounded_key( &mut self, value: Option<StorageKeyRequirements>, )

Sets Encryption key storage requirements.

fn set_requires_identity_decryption_bounded_key( &mut self, value: Option<StorageKeyRequirements>, )

Sets Decryption key storage requirements.

Implementors