DataContractConfigV1

Struct DataContractConfigV1 

pub struct DataContractConfigV1 {
    pub can_be_deleted: bool,
    pub readonly: bool,
    pub keeps_history: bool,
    pub documents_keep_history_contract_default: bool,
    pub documents_mutable_contract_default: bool,
    pub documents_can_be_deleted_contract_default: bool,
    pub requires_identity_encryption_bounded_key: Option<StorageKeyRequirements>,
    pub requires_identity_decryption_bounded_key: Option<StorageKeyRequirements>,
    pub sized_integer_types: bool,
}

Fields

can_be_deleted: bool

Can the contract ever be deleted. If the contract is deleted, so should be all documents associated with it. TODO: There should also be a way to “stop” the contract - contract and documents are kept in the system, but no new documents can be added to it

readonly: bool

Is the contract mutable. Means that the document definitions can be changed or new document definitions can be added to the contract

keeps_history: bool

Does the contract keep history when the contract itself changes

documents_keep_history_contract_default: bool

Do documents in the contract keep history. This is a default for all documents in the contract, but can be overridden by the document itself

documents_mutable_contract_default: bool

Are documents in the contract mutable? This specifies whether the documents can be changed. This is a default for all document types in the contract, but can be overridden by the document type config.

documents_can_be_deleted_contract_default: bool

Can documents in the contract be deleted? This specifies whether the documents can be deleted. This is a default for all document types in the contract, but can be overridden by the document types itself.

requires_identity_encryption_bounded_key: Option<StorageKeyRequirements>

Encryption key storage requirements

requires_identity_decryption_bounded_key: Option<StorageKeyRequirements>

Decryption key storage requirements

sized_integer_types: bool

Use sized integer Rust types for integer property type based on validation rules

Implementations