pub struct DataContractConfigV2 {
pub can_be_deleted: bool,
pub readonly: bool,
pub keeps_history: bool,
pub documents_keep_history_contract_default: bool,
pub documents_mutable_contract_default: bool,
pub documents_can_be_deleted_contract_default: bool,
pub requires_identity_encryption_bounded_key: Option<StorageKeyRequirements>,
pub requires_identity_decryption_bounded_key: Option<StorageKeyRequirements>,
pub sized_integer_types: bool,
pub moderation: Option<ContractModerationConfig>,
}Expand description
Config V2 (protocol version 14): V1 plus the optional contract moderation declaration.
From protocol version 14 this is the config of every new contract, moderated or not; the config version follows the platform version, not the config’s content.
Fields
can_be_deleted: boolCan the contract ever be deleted. If the contract is deleted, so should be all documents associated with it.
readonly: boolIs the contract mutable. Means that the document definitions can be changed or new document definitions can be added to the contract
keeps_history: boolDoes the contract keep history when the contract itself changes
documents_keep_history_contract_default: boolDo documents in the contract keep history. This is a default for all documents in the contract, but can be overridden by the document itself
documents_mutable_contract_default: boolAre documents in the contract mutable? This specifies whether the documents can be changed. This is a default for all document types in the contract, but can be overridden by the document type config.
documents_can_be_deleted_contract_default: boolCan documents in the contract be deleted? This specifies whether the documents can be deleted. This is a default for all document types in the contract, but can be overridden by the document types itself.
requires_identity_encryption_bounded_key: Option<StorageKeyRequirements>Encryption key storage requirements
requires_identity_decryption_bounded_key: Option<StorageKeyRequirements>Decryption key storage requirements
sized_integer_types: boolUse sized integer Rust types for integer property type based on validation rules
moderation: Option<ContractModerationConfig>The moderation lists the contract keeps and who edits them, None for an unmoderated
contract.
Implementations
Sourceimpl DataContractConfigV2
impl DataContractConfigV2
pub fn default_with_version() -> DataContractConfig