pub enum CreatedDataContract {
V0(CreatedDataContractV0),
}Expand description
The created data contract is a intermediate structure that can be consumed by a contract create state transition.
Variants
Implementations
Sourceimpl CreatedDataContract
impl CreatedDataContract
pub fn data_contract_owned(self) -> DataContract
pub fn data_contract_and_identity_nonce(self) -> (DataContract, IdentityNonce)
pub fn data_contract(&self) -> &DataContract
pub fn data_contract_mut(&mut self) -> &mut DataContract
pub fn identity_nonce(&self) -> IdentityNonce
pub fn from_contract_and_identity_nonce( data_contract: DataContract, identity_nonce: IdentityNonce, platform_version: &PlatformVersion, ) -> Result<CreatedDataContract, ProtocolError>
pub fn from_object( raw_object: Value, full_validation: bool, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>