pub enum DataContractFactory {
V0(DataContractFactoryV0),
}Expand description
Data Contract Factory
This module is responsible for creating instances of data contracts.
Versioning
The factory is versioned because the process of creating data contracts can change over time. Changes may be due to modifications in contract requirements, alterations in the contract structure, or evolution in the dependencies of the contract. Versioning allows for these changes to be tracked and managed effectively, providing flexibility to handle different versions of data contracts as needed.
Variants
V0(DataContractFactoryV0)
The version 0 implementation of the data contract factory.
Implementations
Sourceimpl DataContractFactory
impl DataContractFactory
Sourcepub fn new(protocol_version: u32) -> Result<Self, ProtocolError>
pub fn new(protocol_version: u32) -> Result<Self, ProtocolError>
Create a new data contract factory knowing versions
Sourcepub fn create_with_value_config(
&self,
owner_id: Identifier,
identity_nonce: IdentityNonce,
documents: Value,
config: Option<Value>,
definitions: Option<Value>,
) -> Result<CreatedDataContract, ProtocolError>
pub fn create_with_value_config( &self, owner_id: Identifier, identity_nonce: IdentityNonce, documents: Value, config: Option<Value>, definitions: Option<Value>, ) -> Result<CreatedDataContract, ProtocolError>
Create a DataContract using a
Sourcepub fn create(
&self,
owner_id: Identifier,
identity_nonce: IdentityNonce,
documents: Value,
config: Option<DataContractConfig>,
definitions: Option<Value>,
) -> Result<CreatedDataContract, ProtocolError>
pub fn create( &self, owner_id: Identifier, identity_nonce: IdentityNonce, documents: Value, config: Option<DataContractConfig>, definitions: Option<Value>, ) -> Result<CreatedDataContract, ProtocolError>
Create a DataContract
Sourcepub fn create_from_object(
&self,
data_contract_object: Value,
skip_validation: bool,
) -> Result<DataContract, ProtocolError>
pub fn create_from_object( &self, data_contract_object: Value, skip_validation: bool, ) -> Result<DataContract, ProtocolError>
Create a DataContract from a plain object
Sourcepub fn create_from_buffer(
&self,
buffer: Vec<u8>,
skip_validation: bool,
) -> Result<DataContract, ProtocolError>
pub fn create_from_buffer( &self, buffer: Vec<u8>, skip_validation: bool, ) -> Result<DataContract, ProtocolError>
Create a DataContract from a buffer
Sourcepub fn create_data_contract_create_transition(
&self,
created_data_contract: CreatedDataContract,
) -> Result<DataContractCreateTransition, ProtocolError>
pub fn create_data_contract_create_transition( &self, created_data_contract: CreatedDataContract, ) -> Result<DataContractCreateTransition, ProtocolError>
Create a DataContractCreateTransition
Sourcepub fn create_data_contract_update_transition(
&self,
data_contract: DataContract,
identity_contract_nonce: IdentityNonce,
) -> Result<DataContractUpdateTransition, ProtocolError>
pub fn create_data_contract_update_transition( &self, data_contract: DataContract, identity_contract_nonce: IdentityNonce, ) -> Result<DataContractUpdateTransition, ProtocolError>
Create a DataContractUpdateTransition