pub enum DataContractMismatch {
Id,
Config,
Version,
OwnerId,
SchemaDefs,
DocumentSchemas,
Groups,
Tokens,
Keywords,
Description,
FormatVersionMismatch,
V0Mismatch,
}Expand description
Represents a field mismatch between two DataContractInSerializationFormat::V1
variants, or indicates a format version mismatch.
Used to diagnose why two data contracts are not considered equal when ignoring auto-generated fields.
Variants
Id
The id fields are not equal.
Config
The config fields are not equal.
Version
The version fields are not equal.
OwnerId
The owner_id fields are not equal.
SchemaDefs
The schema_defs fields are not equal.
DocumentSchemas
The document_schemas fields are not equal.
Groups
The groups fields are not equal.
Tokens
The tokens fields are not equal.
Keywords
The keywords fields are not equal.
Description
The description fields are not equal.
FormatVersionMismatch
The two variants are of different serialization formats (e.g., V0 vs V1).
V0Mismatch
The two variants are different in V0.