pub struct DataContractFacade { /* private fields */ }Expand description
Data Contract Facade
This module acts as a simplified, high-level interface to a more complex body of code. It forwards requests to appropriate subsystems.
Versioning
In Dash Platform, facades are not versioned because the interface they provide remains stable, even when changes occur in the underlying system. Since these modifications do not affect the facade’s interface, versioning is not necessary. The primary function of the facade is to provide a stable API to the rest of the system, effectively isolating consumers of the API from changes in the underlying implementation.
Implementations
Sourceimpl DataContractFacade
impl DataContractFacade
pub fn new(protocol_version: u32) -> Result<Self, ProtocolError>
Sourcepub fn create(
&self,
owner_id: Identifier,
identity_nonce: IdentityNonce,
documents: Value,
config: Option<Value>,
definitions: Option<Value>,
) -> Result<CreatedDataContract, ProtocolError>
pub fn create( &self, owner_id: Identifier, identity_nonce: IdentityNonce, documents: Value, config: Option<Value>, definitions: Option<Value>, ) -> Result<CreatedDataContract, ProtocolError>
Create Data Contract
Sourcepub fn create_from_object(
&self,
raw_data_contract: Value,
skip_validation: bool,
) -> Result<DataContract, ProtocolError>
pub fn create_from_object( &self, raw_data_contract: Value, skip_validation: bool, ) -> Result<DataContract, ProtocolError>
Create Data Contract from plain object
Sourcepub fn create_from_buffer(
&self,
buffer: Vec<u8>,
skip_validation: bool,
) -> Result<DataContract, ProtocolError>
pub fn create_from_buffer( &self, buffer: Vec<u8>, skip_validation: bool, ) -> Result<DataContract, ProtocolError>
Create Data Contract from buffer
Sourcepub fn create_data_contract_create_transition(
&self,
created_data_contract: CreatedDataContract,
) -> Result<DataContractCreateTransition, ProtocolError>
pub fn create_data_contract_create_transition( &self, created_data_contract: CreatedDataContract, ) -> Result<DataContractCreateTransition, ProtocolError>
Create Data Contract Create State Transition
Sourcepub fn create_data_contract_update_transition(
&self,
data_contract: DataContract,
identity_contract_nonce: IdentityNonce,
) -> Result<DataContractUpdateTransition, ProtocolError>
pub fn create_data_contract_update_transition( &self, data_contract: DataContract, identity_contract_nonce: IdentityNonce, ) -> Result<DataContractUpdateTransition, ProtocolError>
Create Data Contract Update State Transition