DocumentV0Setters

Trait DocumentV0Setters 

pub trait DocumentV0Setters: DocumentV0Getters {
Show 26 methods // Required methods fn set_id(&mut self, id: Identifier); fn set_owner_id(&mut self, owner_id: Identifier); fn set_properties(&mut self, properties: BTreeMap<String, Value>); fn set_revision(&mut self, revision: Option<Revision>); fn set_created_at(&mut self, created_at: Option<TimestampMillis>); fn set_updated_at(&mut self, updated_at: Option<TimestampMillis>); fn set_created_at_block_height( &mut self, created_at_block_height: Option<u64>, ); fn set_updated_at_block_height( &mut self, updated_at_block_height: Option<u64>, ); fn set_created_at_core_block_height( &mut self, created_at_core_block_height: Option<u32>, ); fn set_updated_at_core_block_height( &mut self, updated_at_core_block_height: Option<u32>, ); fn set_transferred_at_core_block_height( &mut self, transferred_at_core_block_height: Option<u32>, ); fn set_transferred_at_block_height( &mut self, transferred_at_block_height: Option<u64>, ); fn set_transferred_at(&mut self, transferred_at: Option<TimestampMillis>); fn bump_revision(&mut self); fn set_creator_id(&mut self, creator_id: Option<Identifier>); // Provided methods fn set(&mut self, path: &str, value: Value) { ... } fn remove(&mut self, path: &str) -> Option<Value> { ... } fn set_u8(&mut self, property_name: &str, value: u8) { ... } fn set_i8(&mut self, property_name: &str, value: i8) { ... } fn set_u16(&mut self, property_name: &str, value: u16) { ... } fn set_i16(&mut self, property_name: &str, value: i16) { ... } fn set_u32(&mut self, property_name: &str, value: u32) { ... } fn set_i32(&mut self, property_name: &str, value: i32) { ... } fn set_u64(&mut self, property_name: &str, value: u64) { ... } fn set_i64(&mut self, property_name: &str, value: i64) { ... } fn set_bytes(&mut self, property_name: &str, value: Vec<u8>) { ... }
}

Required Methods

fn set_id(&mut self, id: Identifier)

Sets the unique document ID.

fn set_owner_id(&mut self, owner_id: Identifier)

Sets the ID of the document’s owner.

fn set_properties(&mut self, properties: BTreeMap<String, Value>)

Sets the document’s properties (data).

fn set_revision(&mut self, revision: Option<Revision>)

Sets the document revision.

fn set_created_at(&mut self, created_at: Option<TimestampMillis>)

Sets the time in milliseconds that the document was created.

fn set_updated_at(&mut self, updated_at: Option<TimestampMillis>)

Sets the time in milliseconds that the document was last updated.

fn set_created_at_block_height(&mut self, created_at_block_height: Option<u64>)

fn set_updated_at_block_height(&mut self, updated_at_block_height: Option<u64>)

fn set_created_at_core_block_height( &mut self, created_at_core_block_height: Option<u32>, )

fn set_updated_at_core_block_height( &mut self, updated_at_core_block_height: Option<u32>, )

fn set_transferred_at_core_block_height( &mut self, transferred_at_core_block_height: Option<u32>, )

fn set_transferred_at_block_height( &mut self, transferred_at_block_height: Option<u64>, )

fn set_transferred_at(&mut self, transferred_at: Option<TimestampMillis>)

fn bump_revision(&mut self)

fn set_creator_id(&mut self, creator_id: Option<Identifier>)

Sets the creator identifier of the document. This is applicable if the document’s schema requires this information.

Parameters
  • creator_id: An Option<Identifier> to set as the document’s creator ID. None indicates the creator ID is not available.

Provided Methods

fn set(&mut self, path: &str, value: Value)

Set the value under the given path. The path supports syntax from the lodash JS library. Example: “root.people[0].name”. If parents are not present, they will be automatically created.

fn remove(&mut self, path: &str) -> Option<Value>

Removes the value under the given path. The path supports syntax from the lodash JS library. Example: “root.people[0].name”. If parents are not present, they will be automatically created.

fn set_u8(&mut self, property_name: &str, value: u8)

Sets a u8 value for the specified property name.

fn set_i8(&mut self, property_name: &str, value: i8)

Sets an i8 value for the specified property name.

fn set_u16(&mut self, property_name: &str, value: u16)

Sets a u16 value for the specified property name.

fn set_i16(&mut self, property_name: &str, value: i16)

Sets an i16 value for the specified property name.

fn set_u32(&mut self, property_name: &str, value: u32)

Sets a u32 value for the specified property name.

fn set_i32(&mut self, property_name: &str, value: i32)

Sets an i32 value for the specified property name.

fn set_u64(&mut self, property_name: &str, value: u64)

Sets a u64 value for the specified property name.

fn set_i64(&mut self, property_name: &str, value: i64)

Sets an i64 value for the specified property name.

fn set_bytes(&mut self, property_name: &str, value: Vec<u8>)

Sets a Vec<u8> (byte array) value for the specified property name.

Implementors