pub enum KnownCostItem {
Show 14 variants
StorageDiskUsageCreditPerByte,
StorageProcessingCreditPerByte,
StorageLoadCreditPerByte,
NonStorageLoadCreditPerByte,
StorageSeekCost,
FetchIdentityBalanceProcessingCost,
FetchSingleIdentityKeyProcessingCost,
SingleSHA256(usize),
Blake3(usize),
VerifySignatureEcdsaSecp256k1,
VerifySignatureBLS12_381,
VerifySignatureEcdsaHash160,
VerifySignatureBip13ScriptHash,
VerifySignatureEddsa25519Hash160,
}Expand description
A Known Cost Item is an item that changes costs depending on the Epoch
Variants
StorageDiskUsageCreditPerByte
The storage cost used when writing bytes
StorageProcessingCreditPerByte
The processing cost used when writing bytes
StorageLoadCreditPerByte
The processing cost used when loading bytes from storage
NonStorageLoadCreditPerByte
The processing cost used when loading bytes not from storage
StorageSeekCost
The cost used when performing a disk seek
FetchIdentityBalanceProcessingCost
The cost for fetching an identity balance
FetchSingleIdentityKeyProcessingCost
The cost for fetching an identity key
SingleSHA256(usize)
The cost for a Single SHA256 operation, with a specific size
Blake3(usize)
The cost for a Blake3 operation, with a specific size
VerifySignatureEcdsaSecp256k1
The cost for a EcdsaSecp256k1 signature verification
VerifySignatureBLS12_381
The cost for a BLS12_381 signature verification
VerifySignatureEcdsaHash160
The cost for a EcdsaHash160 signature verification
VerifySignatureBip13ScriptHash
The cost for a Bip13ScriptHash signature verification
VerifySignatureEddsa25519Hash160
The cost for a Eddsa25519Hash160 signature verification
Implementations
Sourceimpl KnownCostItem
impl KnownCostItem
pub fn lookup_cost(&self, fee_version: &FeeVersion) -> Credits
pub fn lookup_cost_on_epoch<T: EpochCosts>( &self, epoch: &T, cached_fee_version: &CachedEpochIndexFeeVersions, ) -> Credits