EpochCosts

Trait EpochCosts 

pub trait EpochCosts {
    // Required methods
    fn active_fee_version(
        &self,
        cached_fee_version: &CachedEpochIndexFeeVersions,
    ) -> &'static FeeVersion;
    fn cost_for_known_cost_item(
        &self,
        cached_fee_version: &CachedEpochIndexFeeVersions,
        cost_item: KnownCostItem,
    ) -> Credits;
}
Costs for Epochs

Required Methods

fn active_fee_version( &self, cached_fee_version: &CachedEpochIndexFeeVersions, ) -> &'static FeeVersion

Get the closest epoch in the past that has a cost table This is where the base costs last changed

fn cost_for_known_cost_item( &self, cached_fee_version: &CachedEpochIndexFeeVersions, cost_item: KnownCostItem, ) -> Credits

Get the cost for the known cost item

Implementors