pub struct FeeRefunds(pub CreditsPerEpochByIdentifier);Expand description
Fee refunds to identities based on removed data from specific epochs
Tuple Fields
0: CreditsPerEpochByIdentifierImplementations
Sourceimpl FeeRefunds
impl FeeRefunds
Sourcepub fn from_storage_removal<I, C, E>(
storage_removal: I,
current_epoch_index: EpochIndex,
epochs_per_era: u16,
previous_fee_versions: &CachedEpochIndexFeeVersions,
) -> Result<Self, ProtocolError>
pub fn from_storage_removal<I, C, E>( storage_removal: I, current_epoch_index: EpochIndex, epochs_per_era: u16, previous_fee_versions: &CachedEpochIndexFeeVersions, ) -> Result<Self, ProtocolError>
Create fee refunds from GroveDB’s StorageRemovalPerEpochByIdentifier
Sourcepub fn checked_add_assign(&mut self, rhs: Self) -> Result<(), ProtocolError>
pub fn checked_add_assign(&mut self, rhs: Self) -> Result<(), ProtocolError>
Adds and self assigns result between two Fee Results
Sourcepub fn sum_per_epoch(self) -> CreditsPerEpoch
pub fn sum_per_epoch(self) -> CreditsPerEpoch
Sums the fee result among all identities
Sourcepub fn calculate_all_refunds_except_identity(
&self,
identity_id: Identifier,
) -> BTreeMap<Identifier, Credits>
pub fn calculate_all_refunds_except_identity( &self, identity_id: Identifier, ) -> BTreeMap<Identifier, Credits>
Calculates a refund amount of credits per identity excluding specified identity id
Sourcepub fn calculate_refunds_amount_for_identity(
&self,
identity_id: Identifier,
) -> Option<Credits>
pub fn calculate_refunds_amount_for_identity( &self, identity_id: Identifier, ) -> Option<Credits>
Calculates a refund amount of credits for specified identity id