pub enum MergeIdentityNonceResult {
InvalidNonce,
NonceTooFarInFuture,
NonceTooFarInPast,
NonceAlreadyPresentAtTip,
NonceAlreadyPresentInPast(u64),
MergeIdentityNonceSuccess(IdentityNonce),
}Expand description
The result of the merge of the identity contract nonce
Variants
InvalidNonce
The nonce is an invalid value This could be 0
NonceTooFarInFuture
The nonce is too far in the future
NonceTooFarInPast
The nonce is too far in the past
NonceAlreadyPresentAtTip
The nonce is already present at the tip
NonceAlreadyPresentInPast(u64)
The nonce is already present in the past
MergeIdentityNonceSuccess(IdentityNonce)
The merge is a success
Implementations