macro_rules! assert_state_consensus_errors {
($validation_result: expr, $variant: path, $expected_errors_count: expr) => { ... };
}Expand description
Assert that all validation error belong to a certain enum variant of state consensus errors and extracts all the errors from enum to a vector