build_token_purchase_from_shielded_pool_transition

Function build_token_purchase_from_shielded_pool_transition 

pub fn build_token_purchase_from_shielded_pool_transition<P: OrchardProver>(
    token_id: Identifier,
    data_contract_id: Identifier,
    token_contract_position: TokenContractPosition,
    recipient: &OrchardAddress,
    recipient_fvk: &FullViewingKey,
    token_count: TokenAmount,
    total_agreed_price: Credits,
    memo: [u8; 36],
    fee_payer: ShieldedFeePayer<'_>,
    prover: &P,
    platform_version: &PlatformVersion,
) -> Result<(StateTransition, Credits), ProtocolError>
Builds a TokenPurchaseFromShieldedPool: token_count tokens are bought at total_agreed_price credits (which must match the token’s direct purchase price) paid out of the credit shielded pool together with the fee, and minted into a note for recipient in the token’s shielded pool. Returns the transition and the fee paid.