pub fn serialize_authorized_bundle(
bundle: &Bundle<Authorized, i64, DashMemo>,
) -> SerializedBundleExpand description
Serializes an authorized Orchard bundle into the raw fields used by state transition constructors.
pub fn serialize_authorized_bundle(
bundle: &Bundle<Authorized, i64, DashMemo>,
) -> SerializedBundleSerializes an authorized Orchard bundle into the raw fields used by state transition constructors.