pub struct SerializedBundle {
pub actions: Vec<SerializedAction>,
pub flags: u8,
pub value_balance: i64,
pub anchor: [u8; 32],
pub proof: Vec<u8>,
pub binding_signature: [u8; 64],
}Expand description
The serialized fields extracted from an authorized Orchard bundle, ready for use by state transition constructors.
Fields
actions: Vec<SerializedAction>Serialized Orchard actions (spends + outputs).
flags: u8Bundle flags byte.
value_balance: i64Net value balance (positive = value leaving the shielded pool).
anchor: [u8; 32]Sinsemilla root of the Orchard note commitment tree (32 bytes).
This is the Orchard Anchor — the root hash of the depth-32 Sinsemilla
Merkle tree over extracted note commitments (cmx values).
proof: Vec<u8>Halo 2 proof bytes.
binding_signature: [u8; 64]Binding signature (64 bytes).