token_pool_fee_bundle_extra_sighash_data

Function token_pool_fee_bundle_extra_sighash_data 

pub fn token_pool_fee_bundle_extra_sighash_data(
    state_transition_type: u8,
    token_id: &[u8; 32],
    token_actions: &[SerializedAction],
    platform_version: &PlatformVersion,
) -> Result<Vec<u8>, ProtocolError>
Extra sighash data of the credit pool fee bundle of an identity-less token pool transition: the state transition type, the token id and a digest of the token bundle’s actions, so the fee bundle can only ever pay for that exact token bundle.