token_unshield_with_shielded_fee_extra_sighash_data

Function token_unshield_with_shielded_fee_extra_sighash_data 

pub fn token_unshield_with_shielded_fee_extra_sighash_data(
    token_id: &[u8; 32],
    recipient_id: &[u8; 32],
    amount: u64,
    platform_version: &PlatformVersion,
) -> Result<Vec<u8>, ProtocolError>
Extra sighash data of the token bundle of a TokenUnshieldWithShieldedFee: the state transition type, the token id, the recipient and the amount, so the bundle cannot be replayed against another token, recipient or amount.