identity_id_from_input_addresses

Function identity_id_from_input_addresses 

pub fn identity_id_from_input_addresses(
    input_addresses: &BTreeMap<PlatformAddress, (AddressNonce, Credits)>,
) -> Result<Identifier, ProtocolError>
Helper that computes the identity ID from input addresses and nonces. Nonces should represent state after creation of the identity (eg. be incremented by 1).

This is the canonical way to derive the deterministic identity ID from address-funded identity creation inputs.