pub struct BatchTransitionV0 {
pub owner_id: Identifier,
pub transitions: Vec<DocumentTransition>,
pub user_fee_increase: UserFeeIncrease,
pub signature_public_key_id: KeyID,
pub signature: BinaryData,
}Fields
owner_id: Identifiertransitions: Vec<DocumentTransition>user_fee_increase: UserFeeIncreasesignature_public_key_id: KeyIDsignature: BinaryDataTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for BatchTransitionV0
impl<'__de, __Context> BorrowDecode<'__de, __Context> for BatchTransitionV0
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for BatchTransitionV0
impl Clone for BatchTransitionV0
Sourcefn clone(&self) -> BatchTransitionV0
fn clone(&self) -> BatchTransitionV0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchTransitionV0
impl Debug for BatchTransitionV0
Sourceimpl<__Context> Decode<__Context> for BatchTransitionV0
impl<__Context> Decode<__Context> for BatchTransitionV0
Sourceimpl Default for BatchTransitionV0
impl Default for BatchTransitionV0
Sourcefn default() -> BatchTransitionV0
fn default() -> BatchTransitionV0
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BatchTransitionV0
impl<'de> Deserialize<'de> for BatchTransitionV0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DocumentsBatchTransitionAccessorsV0 for BatchTransitionV0
impl DocumentsBatchTransitionAccessorsV0 for BatchTransitionV0
Sourcefn transitions_iter(&self) -> Self::IterType<'_>
fn transitions_iter(&self) -> Self::IterType<'_>
Iterator for BatchedTransitionRef items in version 0.
Sourcefn transitions_len(&self) -> usize
fn transitions_len(&self) -> usize
Returns the total number of transitions (document and token) in version 0.
Sourcefn transitions_are_empty(&self) -> bool
fn transitions_are_empty(&self) -> bool
Checks if there are no transitions in version 0.
Sourcefn first_transition(&self) -> Option<BatchedTransitionRef<'_>>
fn first_transition(&self) -> Option<BatchedTransitionRef<'_>>
Returns the first transition, if it exists, as a BatchedTransitionRef.
Sourcetype IterType<'a> = Map<Iter<'a, DocumentTransition>, fn(&'a DocumentTransition) -> BatchedTransitionRef<'a>>
where
Self: 'a
type IterType<'a> = Map<Iter<'a, DocumentTransition>, fn(&'a DocumentTransition) -> BatchedTransitionRef<'a>> where Self: 'a
Associated type for the iterator.
fn first_transition_mut(&mut self) -> Option<BatchedTransitionMutRef<'_>>
fn contains_document_transition(&self) -> bool
fn contains_token_transition(&self) -> bool
Sourceimpl DocumentsBatchTransitionMethodsV0 for BatchTransitionV0
impl DocumentsBatchTransitionMethodsV0 for BatchTransitionV0
fn new_document_creation_transition_from_document<S: Signer<IdentityPublicKey>>( document: Document, document_type: DocumentTypeRef<'_>, entropy: [u8; 32], identity_public_key: &IdentityPublicKey, identity_contract_nonce: IdentityNonce, user_fee_increase: UserFeeIncrease, token_payment_info: Option<TokenPaymentInfo>, signer: &S, platform_version: &PlatformVersion, options: Option<StateTransitionCreationOptions>, ) -> Result<StateTransition, ProtocolError>
fn new_document_replacement_transition_from_document<S: Signer<IdentityPublicKey>>( document: Document, document_type: DocumentTypeRef<'_>, identity_public_key: &IdentityPublicKey, identity_contract_nonce: IdentityNonce, user_fee_increase: UserFeeIncrease, token_payment_info: Option<TokenPaymentInfo>, signer: &S, platform_version: &PlatformVersion, options: Option<StateTransitionCreationOptions>, ) -> Result<StateTransition, ProtocolError>
fn new_document_transfer_transition_from_document<S: Signer<IdentityPublicKey>>( document: Document, document_type: DocumentTypeRef<'_>, recipient_owner_id: Identifier, identity_public_key: &IdentityPublicKey, identity_contract_nonce: IdentityNonce, user_fee_increase: UserFeeIncrease, token_payment_info: Option<TokenPaymentInfo>, signer: &S, platform_version: &PlatformVersion, options: Option<StateTransitionCreationOptions>, ) -> Result<StateTransition, ProtocolError>
fn new_document_deletion_transition_from_document<S: Signer<IdentityPublicKey>>( document: Document, document_type: DocumentTypeRef<'_>, identity_public_key: &IdentityPublicKey, identity_contract_nonce: IdentityNonce, user_fee_increase: UserFeeIncrease, token_payment_info: Option<TokenPaymentInfo>, signer: &S, platform_version: &PlatformVersion, options: Option<StateTransitionCreationOptions>, ) -> Result<StateTransition, ProtocolError>
fn new_document_update_price_transition_from_document<S: Signer<IdentityPublicKey>>( document: Document, document_type: DocumentTypeRef<'_>, price: Credits, identity_public_key: &IdentityPublicKey, identity_contract_nonce: IdentityNonce, user_fee_increase: UserFeeIncrease, token_payment_info: Option<TokenPaymentInfo>, signer: &S, platform_version: &PlatformVersion, options: Option<StateTransitionCreationOptions>, ) -> Result<StateTransition, ProtocolError>
fn new_document_purchase_transition_from_document<S: Signer<IdentityPublicKey>>( document: Document, document_type: DocumentTypeRef<'_>, new_owner_id: Identifier, price: Credits, identity_public_key: &IdentityPublicKey, identity_contract_nonce: IdentityNonce, user_fee_increase: UserFeeIncrease, token_payment_info: Option<TokenPaymentInfo>, signer: &S, platform_version: &PlatformVersion, options: Option<StateTransitionCreationOptions>, ) -> Result<StateTransition, ProtocolError>
fn set_transitions(&mut self, transitions: Vec<BatchedTransition>)
fn set_identity_contract_nonce( &mut self, identity_contract_nonce: IdentityNonce, )
fn all_document_purchases_amount( &self, ) -> Result<Option<Credits>, ProtocolError>
fn all_conflicting_index_collateral_voting_funds( &self, ) -> Result<Option<Credits>, ProtocolError>
fn combined_security_level_requirement( &self, get_data_contract_security_level_requirement: Option<impl Fn(Identifier, String) -> Result<SecurityLevel, ProtocolError>>, ) -> Result<Vec<SecurityLevel>, ProtocolError>
Sourceimpl Encode for BatchTransitionV0
impl Encode for BatchTransitionV0
Sourceimpl FeatureVersioned for BatchTransitionV0
impl FeatureVersioned for BatchTransitionV0
fn feature_version(&self) -> FeatureVersion
Sourceimpl<'a> From<&'a BatchTransitionV0> for BatchTransitionV0Signable<'a>
impl<'a> From<&'a BatchTransitionV0> for BatchTransitionV0Signable<'a>
Sourcefn from(original: &'a BatchTransitionV0) -> Self
fn from(original: &'a BatchTransitionV0) -> Self
Converts to this type from the input type.
Sourceimpl From<BatchTransitionV0> for BatchTransition
impl From<BatchTransitionV0> for BatchTransition
Sourcefn from(value: BatchTransitionV0) -> Self
fn from(value: BatchTransitionV0) -> Self
Converts to this type from the input type.
Sourceimpl From<BatchTransitionV0> for StateTransition
impl From<BatchTransitionV0> for StateTransition
Sourcefn from(value: BatchTransitionV0) -> Self
fn from(value: BatchTransitionV0) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for BatchTransitionV0
impl PartialEq for BatchTransitionV0
Sourceimpl Serialize for BatchTransitionV0
impl Serialize for BatchTransitionV0
Sourceimpl Signable for BatchTransitionV0
impl Signable for BatchTransitionV0
fn signable_bytes(&self) -> Result<Vec<u8>, ProtocolError>
Sourceimpl StateTransitionFieldTypes for BatchTransitionV0
impl StateTransitionFieldTypes for BatchTransitionV0
fn binary_property_paths() -> Vec<&'static str>
fn identifiers_property_paths() -> Vec<&'static str>
fn signature_property_paths() -> Vec<&'static str>
Sourceimpl StateTransitionHasUserFeeIncrease for BatchTransitionV0
impl StateTransitionHasUserFeeIncrease for BatchTransitionV0
Sourcefn user_fee_increase(&self) -> UserFeeIncrease
fn user_fee_increase(&self) -> UserFeeIncrease
returns the fee multiplier
Sourcefn set_user_fee_increase(&mut self, user_fee_increase: UserFeeIncrease)
fn set_user_fee_increase(&mut self, user_fee_increase: UserFeeIncrease)
set a fee multiplier
Sourceimpl StateTransitionIdentitySigned for BatchTransitionV0
impl StateTransitionIdentitySigned for BatchTransitionV0
fn signature_public_key_id(&self) -> KeyID
fn set_signature_public_key_id(&mut self, key_id: KeyID)
Sourcefn security_level_requirement(&self, _purpose: Purpose) -> Vec<SecurityLevel>
fn security_level_requirement(&self, _purpose: Purpose) -> Vec<SecurityLevel>
Returns minimal key security level that can be used to sign this ST.
Override this method if the ST requires a different security level.
Sourcefn verify_public_key_level_and_purpose(
&self,
public_key: &IdentityPublicKey,
options: StateTransitionSigningOptions,
) -> Result<(), ProtocolError>
fn verify_public_key_level_and_purpose( &self, public_key: &IdentityPublicKey, options: StateTransitionSigningOptions, ) -> Result<(), ProtocolError>
Verifies that the supplied public key has the correct security level
and purpose to sign the state transition
This should only be used for authentication
fn verify_public_key_is_enabled( &self, public_key: &IdentityPublicKey, ) -> Result<(), ProtocolError>
Sourcefn purpose_requirement(&self) -> Vec<Purpose>
fn purpose_requirement(&self) -> Vec<Purpose>
The purpose requirement for the signing key
The default is authentication
However for Withdrawals and Fund Transfers the requirement is TRANSFER
Sourceimpl StateTransitionJsonConvert<'_> for BatchTransitionV0
impl StateTransitionJsonConvert<'_> for BatchTransitionV0
Sourcefn to_json(
&self,
options: JsonStateTransitionSerializationOptions,
) -> Result<JsonValue, ProtocolError>
fn to_json( &self, options: JsonStateTransitionSerializationOptions, ) -> Result<JsonValue, ProtocolError>
Returns the
serde_json::Value instance that encodes: Read moreSourceimpl StateTransitionLike for BatchTransitionV0
impl StateTransitionLike for BatchTransitionV0
Sourcefn modified_data_ids(&self) -> Vec<Identifier>
fn modified_data_ids(&self) -> Vec<Identifier>
Returns ID of the created contract
Sourcefn state_transition_type(&self) -> StateTransitionType
fn state_transition_type(&self) -> StateTransitionType
returns the type of State Transition
Sourcefn unique_identifiers(&self) -> Vec<String>
fn unique_identifiers(&self) -> Vec<String>
We create a list of unique identifiers for the batch
Sourcefn state_transition_protocol_version(&self) -> FeatureVersion
fn state_transition_protocol_version(&self) -> FeatureVersion
returns the protocol version
Sourcefn is_document_state_transition(&self) -> bool
fn is_document_state_transition(&self) -> bool
returns true if state transition is a document state transition
Sourcefn is_data_contract_state_transition(&self) -> bool
fn is_data_contract_state_transition(&self) -> bool
returns true if state transition is a data contract state transition
Sourcefn is_identity_state_transition(&self) -> bool
fn is_identity_state_transition(&self) -> bool
return true if state transition is an identity state transition
Sourcefn is_voting_state_transition(&self) -> bool
fn is_voting_state_transition(&self) -> bool
return true if state transition is a voting state transition
Sourceimpl StateTransitionOwned for BatchTransitionV0
impl StateTransitionOwned for BatchTransitionV0
Sourcefn owner_id(&self) -> Identifier
fn owner_id(&self) -> Identifier
Get owner ID
Sourceimpl StateTransitionValueConvert<'_> for BatchTransitionV0
impl StateTransitionValueConvert<'_> for BatchTransitionV0
Sourcefn to_object(&self, skip_signature: bool) -> Result<Value, ProtocolError>
fn to_object(&self, skip_signature: bool) -> Result<Value, ProtocolError>
Returns the [
platform_value::Value] instance that preserves the Vec<u8> representation
for Identifiers and binary dataSourcefn to_canonical_object(
&self,
skip_signature: bool,
) -> Result<Value, ProtocolError>
fn to_canonical_object( &self, skip_signature: bool, ) -> Result<Value, ProtocolError>
Returns the [
platform_value::Value] instance that preserves the Vec<u8> representation
for Identifiers and binary dataSourcefn to_canonical_cleaned_object(
&self,
skip_signature: bool,
) -> Result<Value, ProtocolError>
fn to_canonical_cleaned_object( &self, skip_signature: bool, ) -> Result<Value, ProtocolError>
Returns the [
platform_value::Value] instance that preserves the Vec<u8> representation
for Identifiers and binary datafn to_cleaned_object( &self, skip_signature: bool, ) -> Result<Value, ProtocolError>
fn from_object(
raw_object: Value,
_platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>where
Self: Sized,
fn from_value_map(
raw_value_map: BTreeMap<String, Value>,
_platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>where
Self: Sized,
fn clean_value(_value: &mut Value) -> Result<(), ProtocolError>
impl StructuralPartialEq for BatchTransitionV0