pub struct DataContractCreateTransitionV0 {
pub data_contract: DataContractInSerializationFormat,
pub identity_nonce: IdentityNonce,
pub user_fee_increase: UserFeeIncrease,
pub signature_public_key_id: KeyID,
pub signature: BinaryData,
}Expand description
DataContractCreateTransitionV0 has the same encoding structure
Fields
data_contract: DataContractInSerializationFormatidentity_nonce: IdentityNonceuser_fee_increase: UserFeeIncreasesignature_public_key_id: KeyIDsignature: BinaryDataTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for DataContractCreateTransitionV0
impl<'__de, __Context> BorrowDecode<'__de, __Context> for DataContractCreateTransitionV0
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for DataContractCreateTransitionV0
impl Clone for DataContractCreateTransitionV0
Sourcefn clone(&self) -> DataContractCreateTransitionV0
fn clone(&self) -> DataContractCreateTransitionV0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataContractCreateTransitionMethodsV0 for DataContractCreateTransitionV0
impl DataContractCreateTransitionMethodsV0 for DataContractCreateTransitionV0
Sourcefn new_from_data_contract<S: Signer<IdentityPublicKey>>(
data_contract: DataContract,
identity_nonce: IdentityNonce,
identity: &PartialIdentity,
key_id: KeyID,
signer: &S,
platform_version: &PlatformVersion,
_feature_version: Option<FeatureVersion>,
) -> Result<StateTransition, ProtocolError>
fn new_from_data_contract<S: Signer<IdentityPublicKey>>( data_contract: DataContract, identity_nonce: IdentityNonce, identity: &PartialIdentity, key_id: KeyID, signer: &S, platform_version: &PlatformVersion, _feature_version: Option<FeatureVersion>, ) -> Result<StateTransition, ProtocolError>
Creates a new instance of the DataContractCreateTransition from the provided data contract. Read more
Sourceimpl<__Context> Decode<__Context> for DataContractCreateTransitionV0
impl<__Context> Decode<__Context> for DataContractCreateTransitionV0
Sourceimpl<'de> Deserialize<'de> for DataContractCreateTransitionV0
impl<'de> Deserialize<'de> for DataContractCreateTransitionV0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FeatureVersioned for DataContractCreateTransitionV0
impl FeatureVersioned for DataContractCreateTransitionV0
fn feature_version(&self) -> FeatureVersion
Sourceimpl<'a> From<&'a DataContractCreateTransitionV0> for DataContractCreateTransitionV0Signable<'a>
impl<'a> From<&'a DataContractCreateTransitionV0> for DataContractCreateTransitionV0Signable<'a>
Sourcefn from(original: &'a DataContractCreateTransitionV0) -> Self
fn from(original: &'a DataContractCreateTransitionV0) -> Self
Converts to this type from the input type.
Sourceimpl From<&DataContractCreateTransitionV0> for StateTransition
impl From<&DataContractCreateTransitionV0> for StateTransition
Sourcefn from(value: &DataContractCreateTransitionV0) -> Self
fn from(value: &DataContractCreateTransitionV0) -> Self
Converts to this type from the input type.
Sourceimpl From<DataContractCreateTransitionV0> for DataContractCreateTransition
impl From<DataContractCreateTransitionV0> for DataContractCreateTransition
Sourcefn from(value: DataContractCreateTransitionV0) -> Self
fn from(value: DataContractCreateTransitionV0) -> Self
Converts to this type from the input type.
Sourceimpl From<DataContractCreateTransitionV0> for StateTransition
impl From<DataContractCreateTransitionV0> for StateTransition
Sourcefn from(value: DataContractCreateTransitionV0) -> Self
fn from(value: DataContractCreateTransitionV0) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for DataContractCreateTransitionV0
impl PartialEq for DataContractCreateTransitionV0
Sourcefn eq(&self, other: &DataContractCreateTransitionV0) -> bool
fn eq(&self, other: &DataContractCreateTransitionV0) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Signable for DataContractCreateTransitionV0
impl Signable for DataContractCreateTransitionV0
fn signable_bytes(&self) -> Result<Vec<u8>, ProtocolError>
Sourceimpl StateTransitionFieldTypes for DataContractCreateTransitionV0
impl StateTransitionFieldTypes for DataContractCreateTransitionV0
fn signature_property_paths() -> Vec<&'static str>
fn identifiers_property_paths() -> Vec<&'static str>
fn binary_property_paths() -> Vec<&'static str>
Sourceimpl StateTransitionHasUserFeeIncrease for DataContractCreateTransitionV0
impl StateTransitionHasUserFeeIncrease for DataContractCreateTransitionV0
Sourcefn user_fee_increase(&self) -> UserFeeIncrease
fn user_fee_increase(&self) -> UserFeeIncrease
returns the fee multiplier
Sourcefn set_user_fee_increase(&mut self, user_fee_increase: UserFeeIncrease)
fn set_user_fee_increase(&mut self, user_fee_increase: UserFeeIncrease)
set a fee multiplier
Sourceimpl StateTransitionIdentitySigned for DataContractCreateTransitionV0
impl StateTransitionIdentitySigned for DataContractCreateTransitionV0
fn signature_public_key_id(&self) -> KeyID
fn set_signature_public_key_id(&mut self, key_id: KeyID)
Sourcefn security_level_requirement(&self, _purpose: Purpose) -> Vec<SecurityLevel>
fn security_level_requirement(&self, _purpose: Purpose) -> Vec<SecurityLevel>
Returns minimal key security level that can be used to sign this ST.
Override this method if the ST requires a different security level.
Sourcefn verify_public_key_level_and_purpose(
&self,
public_key: &IdentityPublicKey,
options: StateTransitionSigningOptions,
) -> Result<(), ProtocolError>
fn verify_public_key_level_and_purpose( &self, public_key: &IdentityPublicKey, options: StateTransitionSigningOptions, ) -> Result<(), ProtocolError>
Verifies that the supplied public key has the correct security level
and purpose to sign the state transition
This should only be used for authentication
fn verify_public_key_is_enabled( &self, public_key: &IdentityPublicKey, ) -> Result<(), ProtocolError>
Sourcefn purpose_requirement(&self) -> Vec<Purpose>
fn purpose_requirement(&self) -> Vec<Purpose>
The purpose requirement for the signing key
The default is authentication
However for Withdrawals and Fund Transfers the requirement is TRANSFER
Sourceimpl StateTransitionJsonConvert<'_> for DataContractCreateTransitionV0
impl StateTransitionJsonConvert<'_> for DataContractCreateTransitionV0
Sourcefn to_json(
&self,
options: JsonStateTransitionSerializationOptions,
) -> Result<JsonValue, ProtocolError>
fn to_json( &self, options: JsonStateTransitionSerializationOptions, ) -> Result<JsonValue, ProtocolError>
Returns the
serde_json::Value instance that encodes: Read moreSourceimpl StateTransitionLike for DataContractCreateTransitionV0
impl StateTransitionLike for DataContractCreateTransitionV0
Sourcefn modified_data_ids(&self) -> Vec<Identifier>
fn modified_data_ids(&self) -> Vec<Identifier>
Returns ID of the created contract
Sourcefn state_transition_type(&self) -> StateTransitionType
fn state_transition_type(&self) -> StateTransitionType
returns the type of State Transition
Sourcefn state_transition_protocol_version(&self) -> FeatureVersion
fn state_transition_protocol_version(&self) -> FeatureVersion
returns the protocol version
Sourcefn unique_identifiers(&self) -> Vec<String>
fn unique_identifiers(&self) -> Vec<String>
unique identifiers for the state transition
This is often only one String except in the case of a documents batch state transition
Sourcefn is_document_state_transition(&self) -> bool
fn is_document_state_transition(&self) -> bool
returns true if state transition is a document state transition
Sourcefn is_data_contract_state_transition(&self) -> bool
fn is_data_contract_state_transition(&self) -> bool
returns true if state transition is a data contract state transition
Sourcefn is_identity_state_transition(&self) -> bool
fn is_identity_state_transition(&self) -> bool
return true if state transition is an identity state transition
Sourcefn is_voting_state_transition(&self) -> bool
fn is_voting_state_transition(&self) -> bool
return true if state transition is a voting state transition
Sourceimpl StateTransitionOwned for DataContractCreateTransitionV0
impl StateTransitionOwned for DataContractCreateTransitionV0
Sourcefn owner_id(&self) -> Identifier
fn owner_id(&self) -> Identifier
Get owner ID
Sourceimpl StateTransitionValueConvert<'_> for DataContractCreateTransitionV0
impl StateTransitionValueConvert<'_> for DataContractCreateTransitionV0
Sourcefn to_object(&self, skip_signature: bool) -> Result<Value, ProtocolError>
fn to_object(&self, skip_signature: bool) -> Result<Value, ProtocolError>
Returns the [
platform_value::Value] instance that preserves the Vec<u8> representation
for Identifiers and binary datafn to_cleaned_object( &self, skip_signature: bool, ) -> Result<Value, ProtocolError>
fn from_object( raw_object: Value, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
fn from_value_map( raw_value_map: BTreeMap<String, Value>, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
fn clean_value(value: &mut Value) -> Result<(), ProtocolError>
Sourcefn to_canonical_object(
&self,
skip_signature: bool,
) -> Result<Value, ProtocolError>
fn to_canonical_object( &self, skip_signature: bool, ) -> Result<Value, ProtocolError>
Returns the [
platform_value::Value] instance that preserves the Vec<u8> representation
for Identifiers and binary dataSourcefn to_canonical_cleaned_object(
&self,
skip_signature: bool,
) -> Result<Value, ProtocolError>
fn to_canonical_cleaned_object( &self, skip_signature: bool, ) -> Result<Value, ProtocolError>
Returns the [
platform_value::Value] instance that preserves the Vec<u8> representation
for Identifiers and binary dataSourceimpl TryFromPlatformVersioned<CreatedDataContract> for DataContractCreateTransitionV0
impl TryFromPlatformVersioned<CreatedDataContract> for DataContractCreateTransitionV0
Sourcetype Error = ProtocolError
type Error = ProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from_platform_versioned(
value: CreatedDataContract,
platform_version: &PlatformVersion,
) -> Result<Self, Self::Error>
fn try_from_platform_versioned( value: CreatedDataContract, platform_version: &PlatformVersion, ) -> Result<Self, Self::Error>
Performs the conversion.
Sourceimpl TryFromPlatformVersioned<DataContract> for DataContractCreateTransitionV0
impl TryFromPlatformVersioned<DataContract> for DataContractCreateTransitionV0
Sourcetype Error = ProtocolError
type Error = ProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from_platform_versioned(
value: DataContract,
platform_version: &PlatformVersion,
) -> Result<Self, Self::Error>
fn try_from_platform_versioned( value: DataContract, platform_version: &PlatformVersion, ) -> Result<Self, Self::Error>
Performs the conversion.
impl JsonSafeFields for DataContractCreateTransitionV0
impl StructuralPartialEq for DataContractCreateTransitionV0