pub struct DataContractCreateTransitionV1 {
pub data_contract: DataContractInSerializationFormat,
pub identity_nonce: IdentityNonce,
pub contract_group: Option<ContractGroupRegistration>,
pub contract_group_memberships: Vec<ContractGroupMembership>,
pub user_fee_increase: UserFeeIncrease,
pub signature_public_key_id: KeyID,
pub signature: BinaryData,
}Expand description
Version 1 of the data contract create transition: version 0 plus contract groups.
contract_group registers a new contract group owned by the transition’s owner (or by the
owners it names); the group id is derived from the owner id and the identity nonce.
contract_group_memberships adds the created contract, one of its document types, or one of
its tokens to contract groups the owner may add to: groups registered earlier by an owner, or
the group registered by this transition. Both are empty on a plain contract creation.
Fields
data_contract: DataContractInSerializationFormatidentity_nonce: IdentityNoncecontract_group: Option<ContractGroupRegistration>contract_group_memberships: Vec<ContractGroupMembership>user_fee_increase: UserFeeIncreasesignature_public_key_id: KeyIDsignature: BinaryDataTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for DataContractCreateTransitionV1
impl<'__de, __Context> BorrowDecode<'__de, __Context> for DataContractCreateTransitionV1
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl<'__de, __Context> BorrowDecodeUntrusted<'__de, __Context> for DataContractCreateTransitionV1
impl<'__de, __Context> BorrowDecodeUntrusted<'__de, __Context> for DataContractCreateTransitionV1
Sourcefn borrow_decode_untrusted<__D: BorrowUntrustedDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode_untrusted<__D: BorrowUntrustedDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Borrow-decode with explicit untrusted field dispatch and resource handling.
Sourceimpl Clone for DataContractCreateTransitionV1
impl Clone for DataContractCreateTransitionV1
Sourcefn clone(&self) -> DataContractCreateTransitionV1
fn clone(&self) -> DataContractCreateTransitionV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataContractCreateTransitionMethodsV0 for DataContractCreateTransitionV1
impl DataContractCreateTransitionMethodsV0 for DataContractCreateTransitionV1
Sourceasync fn new_from_data_contract<S: Signer<IdentityPublicKey>>(
data_contract: DataContract,
identity_nonce: IdentityNonce,
identity: &PartialIdentity,
key_id: KeyID,
signer: &S,
platform_version: &PlatformVersion,
feature_version: Option<FeatureVersion>,
) -> Result<StateTransition, ProtocolError>
async fn new_from_data_contract<S: Signer<IdentityPublicKey>>( data_contract: DataContract, identity_nonce: IdentityNonce, identity: &PartialIdentity, key_id: KeyID, signer: &S, platform_version: &PlatformVersion, feature_version: Option<FeatureVersion>, ) -> Result<StateTransition, ProtocolError>
Creates a new instance of the DataContractCreateTransition from the provided data contract. Read more
Sourceimpl DataContractCreateTransitionMethodsV1 for DataContractCreateTransitionV1
impl DataContractCreateTransitionMethodsV1 for DataContractCreateTransitionV1
Sourceasync fn new_from_data_contract_with_contract_group<S: Signer<IdentityPublicKey>>(
data_contract: DataContract,
identity_nonce: IdentityNonce,
contract_group: Option<ContractGroupRegistration>,
contract_group_memberships: Vec<ContractGroupMembership>,
identity: &PartialIdentity,
key_id: KeyID,
signer: &S,
platform_version: &PlatformVersion,
_feature_version: Option<FeatureVersion>,
) -> Result<StateTransition, ProtocolError>
async fn new_from_data_contract_with_contract_group<S: Signer<IdentityPublicKey>>( data_contract: DataContract, identity_nonce: IdentityNonce, contract_group: Option<ContractGroupRegistration>, contract_group_memberships: Vec<ContractGroupMembership>, identity: &PartialIdentity, key_id: KeyID, signer: &S, platform_version: &PlatformVersion, _feature_version: Option<FeatureVersion>, ) -> Result<StateTransition, ProtocolError>
Creates and signs a data contract create transition that also registers a contract group
and/or adds the created contract, one of its document types, or one of its tokens to
contract groups. Read more
Sourceimpl<__Context> Decode<__Context> for DataContractCreateTransitionV1
impl<__Context> Decode<__Context> for DataContractCreateTransitionV1
Sourceimpl<__Context> DecodeUntrusted<__Context> for DataContractCreateTransitionV1
impl<__Context> DecodeUntrusted<__Context> for DataContractCreateTransitionV1
Sourcefn decode_untrusted<__D: UntrustedDecoder<Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn decode_untrusted<__D: UntrustedDecoder<Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Decode with explicit untrusted field dispatch and resource handling.
Sourceimpl<'de> Deserialize<'de> for DataContractCreateTransitionV1
impl<'de> Deserialize<'de> for DataContractCreateTransitionV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FeatureVersioned for DataContractCreateTransitionV1
impl FeatureVersioned for DataContractCreateTransitionV1
fn feature_version(&self) -> FeatureVersion
Sourceimpl<'a> From<&'a DataContractCreateTransitionV1> for DataContractCreateTransitionV1Signable<'a>
impl<'a> From<&'a DataContractCreateTransitionV1> for DataContractCreateTransitionV1Signable<'a>
Sourcefn from(original: &'a DataContractCreateTransitionV1) -> Self
fn from(original: &'a DataContractCreateTransitionV1) -> Self
Converts to this type from the input type.
Sourceimpl From<&DataContractCreateTransitionV1> for StateTransition
impl From<&DataContractCreateTransitionV1> for StateTransition
Sourcefn from(value: &DataContractCreateTransitionV1) -> Self
fn from(value: &DataContractCreateTransitionV1) -> Self
Converts to this type from the input type.
Sourceimpl From<DataContractCreateTransitionV1> for StateTransition
impl From<DataContractCreateTransitionV1> for StateTransition
Sourcefn from(value: DataContractCreateTransitionV1) -> Self
fn from(value: DataContractCreateTransitionV1) -> Self
Converts to this type from the input type.
Sourceimpl From<DataContractCreateTransitionV1> for DataContractCreateTransition
impl From<DataContractCreateTransitionV1> for DataContractCreateTransition
Sourcefn from(value: DataContractCreateTransitionV1) -> Self
fn from(value: DataContractCreateTransitionV1) -> Self
Converts to this type from the input type.
impl JsonSafeFields for DataContractCreateTransitionV1
Sourceimpl PartialEq for DataContractCreateTransitionV1
impl PartialEq for DataContractCreateTransitionV1
Sourcefn eq(&self, other: &DataContractCreateTransitionV1) -> bool
fn eq(&self, other: &DataContractCreateTransitionV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Signable for DataContractCreateTransitionV1
impl Signable for DataContractCreateTransitionV1
fn signable_bytes(&self) -> Result<Vec<u8>, ProtocolError>
Sourceimpl StateTransitionFieldTypes for DataContractCreateTransitionV1
impl StateTransitionFieldTypes for DataContractCreateTransitionV1
fn signature_property_paths() -> Vec<&'static str>
fn identifiers_property_paths() -> Vec<&'static str>
fn binary_property_paths() -> Vec<&'static str>
Sourceimpl StateTransitionHasUserFeeIncrease for DataContractCreateTransitionV1
impl StateTransitionHasUserFeeIncrease for DataContractCreateTransitionV1
Sourcefn user_fee_increase(&self) -> UserFeeIncrease
fn user_fee_increase(&self) -> UserFeeIncrease
returns the fee multiplier
Sourcefn set_user_fee_increase(&mut self, user_fee_increase: UserFeeIncrease)
fn set_user_fee_increase(&mut self, user_fee_increase: UserFeeIncrease)
set a fee multiplier
Sourceimpl StateTransitionIdentitySigned for DataContractCreateTransitionV1
impl StateTransitionIdentitySigned for DataContractCreateTransitionV1
fn signature_public_key_id(&self) -> KeyID
fn set_signature_public_key_id(&mut self, key_id: KeyID)
Sourcefn security_level_requirement(&self, _purpose: Purpose) -> Vec<SecurityLevel>
fn security_level_requirement(&self, _purpose: Purpose) -> Vec<SecurityLevel>
Returns minimal key security level that can be used to sign this ST.
Override this method if the ST requires a different security level.
Sourcefn verify_public_key_level_and_purpose(
&self,
public_key: &IdentityPublicKey,
options: StateTransitionSigningOptions,
) -> Result<(), ProtocolError>
fn verify_public_key_level_and_purpose( &self, public_key: &IdentityPublicKey, options: StateTransitionSigningOptions, ) -> Result<(), ProtocolError>
Verifies that the supplied public key has the correct security level
and purpose to sign the state transition
This should only be used for authentication
fn verify_public_key_is_enabled( &self, public_key: &IdentityPublicKey, ) -> Result<(), ProtocolError>
Sourcefn purpose_requirement(&self) -> Vec<Purpose>
fn purpose_requirement(&self) -> Vec<Purpose>
The purpose requirement for the signing key
The default is authentication
However for Withdrawals and Fund Transfers the requirement is TRANSFER
Sourceimpl StateTransitionLike for DataContractCreateTransitionV1
impl StateTransitionLike for DataContractCreateTransitionV1
Sourcefn modified_data_ids(&self) -> Vec<Identifier>
fn modified_data_ids(&self) -> Vec<Identifier>
Returns ID of the created contract
Sourcefn state_transition_type(&self) -> StateTransitionType
fn state_transition_type(&self) -> StateTransitionType
returns the type of State Transition
Sourcefn state_transition_protocol_version(&self) -> FeatureVersion
fn state_transition_protocol_version(&self) -> FeatureVersion
returns the protocol version
Sourcefn unique_identifiers(&self) -> Vec<String>
fn unique_identifiers(&self) -> Vec<String>
unique identifiers for the state transition
This is often only one String except in the case of a documents batch state transition
Sourcefn is_document_state_transition(&self) -> bool
fn is_document_state_transition(&self) -> bool
returns true if state transition is a document state transition
Sourcefn is_data_contract_state_transition(&self) -> bool
fn is_data_contract_state_transition(&self) -> bool
returns true if state transition is a data contract state transition
Sourcefn is_identity_state_transition(&self) -> bool
fn is_identity_state_transition(&self) -> bool
return true if state transition is an identity state transition
Sourcefn is_voting_state_transition(&self) -> bool
fn is_voting_state_transition(&self) -> bool
return true if state transition is a voting state transition
Sourceimpl StateTransitionOwned for DataContractCreateTransitionV1
impl StateTransitionOwned for DataContractCreateTransitionV1
Sourcefn owner_id(&self) -> Identifier
fn owner_id(&self) -> Identifier
Get owner ID
impl StructuralPartialEq for DataContractCreateTransitionV1
Sourceimpl TryFromPlatformVersioned<CreatedDataContract> for DataContractCreateTransitionV1
impl TryFromPlatformVersioned<CreatedDataContract> for DataContractCreateTransitionV1
Sourcetype Error = ProtocolError
type Error = ProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from_platform_versioned(
value: CreatedDataContract,
platform_version: &PlatformVersion,
) -> Result<Self, Self::Error>
fn try_from_platform_versioned( value: CreatedDataContract, platform_version: &PlatformVersion, ) -> Result<Self, Self::Error>
Performs the conversion.
Sourceimpl TryFromPlatformVersioned<DataContract> for DataContractCreateTransitionV1
impl TryFromPlatformVersioned<DataContract> for DataContractCreateTransitionV1
Sourcetype Error = ProtocolError
type Error = ProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from_platform_versioned(
value: DataContract,
platform_version: &PlatformVersion,
) -> Result<Self, Self::Error>
fn try_from_platform_versioned( value: DataContract, platform_version: &PlatformVersion, ) -> Result<Self, Self::Error>
Performs the conversion.