#[repr(u8)]pub enum WithdrawalStatus {
QUEUED = 0,
POOLED = 1,
BROADCASTED = 2,
COMPLETE = 3,
EXPIRED = 4,
}Variants
QUEUED = 0
The documents are in the state and waiting to be processed.
POOLED = 1
Pooled happens when we are waiting for signing.
BROADCASTED = 2
We have broadcasted the transaction to core.
COMPLETE = 3
The transaction is now complete.
EXPIRED = 4
We broadcasted the transaction but core never saw it or rejected it.