pub struct TokenPaymentInfoV0 {
pub payment_token_contract_id: Option<Identifier>,
pub token_contract_position: TokenContractPosition,
pub minimum_token_cost: Option<TokenAmount>,
pub maximum_token_cost: Option<TokenAmount>,
pub gas_fees_paid_by: GasFeesPaidBy,
}Fields
payment_token_contract_id: Option<Identifier>By default, we use a token in the same contract, this field must be set if the document requires payment using another contracts token.
token_contract_position: TokenContractPositionIf we are expecting to pay with a token in a contract, which token are we expecting to pay with? We have this set so contract owners can’t switch out to more valuable token. For example if my Data contract
minimum_token_cost: Option<TokenAmount>Minimum token cost, this most often should not be set
maximum_token_cost: Option<TokenAmount>Maximum token cost, this most often should be set If:
- a client does not have this set
- and the data contract allows the price of NFTs to be changed by the data contract’s owner or allowed party. Then:
- The user could see the cost changed on them
gas_fees_paid_by: GasFeesPaidByWho pays the gas fees, this needs to match what the contract allows