pub struct CborCanonicalMap { /* private fields */ }Implementations
Sourceimpl CborCanonicalMap
impl CborCanonicalMap
pub fn new() -> Self
pub fn from_serializable<T>(value: &T) -> Result<Self, ProtocolError>where
T: Serialize,
pub fn from_vector(vec: Vec<(CborValue, CborValue)>) -> Self
pub fn insert(&mut self, key: impl Into<String>, value: impl Into<CborValue>)
pub fn remove(&mut self, key_to_remove: impl Into<CborValue>)
pub fn get_mut(&mut self, key: &CborValue) -> Option<&mut CborValue>
pub fn replace_paths<I, C>(&mut self, paths: I, from: FieldType, to: FieldType)
pub fn replace_path( &mut self, path: &str, from: FieldType, to: FieldType, ) -> Option<()>
pub fn set(&mut self, key: &CborValue, replace_with: CborValue) -> Option<()>
Sourcepub fn sort_canonical(&mut self)
pub fn sort_canonical(&mut self)
From the CBOR RFC on how to sort the keys:
-
If two keys have different lengths, the shorter one sorts earlier;
-
If two keys have the same length, the one with the lower value in (byte-wise) lexical order sorts earlier.
https://datatracker.ietf.org/doc/html/rfc7049#section-3.9
pub fn to_bytes(self) -> Result<Vec<u8>, Error<Error>>
pub fn to_value_unsorted(&self) -> CborValue
pub fn to_value_sorted(self) -> CborValue
pub fn to_value_clone(&mut self) -> CborValue