Struct DPPContractVersions
pub struct DPPContractVersions {
pub max_serialized_size: u32,
pub contract_serialization_version: FeatureVersionBounds,
pub contract_structure_version: u16,
pub created_data_contract_structure: u16,
pub config: FeatureVersionBounds,
pub methods: DataContractMethodVersions,
pub document_type_versions: DocumentTypeVersions,
pub token_versions: TokenVersions,
}Fields
max_serialized_size: u32The maximum that we can store a data contract in the state. There is a possibility that a client sends a state transition serialized in a specific version and that the system re-serializes it to the current version, and in so doing increases it’s size.
contract_serialization_version: FeatureVersionBoundsThis is how we serialize and deserialize a contract
contract_structure_version: u16This is the structure of the Contract as it is defined for code paths
created_data_contract_structure: u16config: FeatureVersionBoundsmethods: DataContractMethodVersionsdocument_type_versions: DocumentTypeVersionstoken_versions: TokenVersionsTrait Implementations
impl Clone for DPPContractVersions
impl Clone for DPPContractVersions
fn clone(&self) -> DPPContractVersions
fn clone(&self) -> DPPContractVersions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for DPPContractVersions
impl Debug for DPPContractVersions
impl Default for DPPContractVersions
impl Default for DPPContractVersions
fn default() -> DPPContractVersions
fn default() -> DPPContractVersions
Returns the “default value” for a type. Read more