Struct PenaltyAmounts
pub struct PenaltyAmounts {
pub identity_id_not_correct: u64,
pub unique_key_already_present: u64,
pub validation_of_added_keys_structure_failure: u64,
pub validation_of_added_keys_proof_of_possession_failure: u64,
pub address_funds_insufficient_balance: u64,
pub shielded_proof_verification_failure: u64,
}Expand description
All of these penalty amounts are in credits
Fields
identity_id_not_correct: u64unique_key_already_present: u64validation_of_added_keys_structure_failure: u64validation_of_added_keys_proof_of_possession_failure: u64address_funds_insufficient_balance: u64Penalty for address funding with insufficient funds for outputs
shielded_proof_verification_failure: u64Penalty for submitting a shield transition with an invalid ZK proof