Struct FeeSignatureVersion
pub struct FeeSignatureVersion {
pub verify_signature_ecdsa_secp256k1: u64,
pub verify_signature_bls12_381: u64,
pub verify_signature_ecdsa_hash160: u64,
pub verify_signature_bip13_script_hash: u64,
pub verify_signature_eddsa25519_hash160: u64,
}Fields
verify_signature_ecdsa_secp256k1: u64verify_signature_bls12_381: u64verify_signature_ecdsa_hash160: u64verify_signature_bip13_script_hash: u64verify_signature_eddsa25519_hash160: u64Trait Implementations
impl<'__de, __Context> BorrowDecode<'__de, __Context> for FeeSignatureVersion
impl<'__de, __Context> BorrowDecode<'__de, __Context> for FeeSignatureVersion
fn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<FeeSignatureVersion, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<FeeSignatureVersion, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.
impl Clone for FeeSignatureVersion
impl Clone for FeeSignatureVersion
fn clone(&self) -> FeeSignatureVersion
fn clone(&self) -> FeeSignatureVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for FeeSignatureVersion
impl Debug for FeeSignatureVersion
impl<__Context> Decode<__Context> for FeeSignatureVersion
impl<__Context> Decode<__Context> for FeeSignatureVersion
fn decode<__D>(decoder: &mut __D) -> Result<FeeSignatureVersion, DecodeError>where
__D: Decoder<Context = __Context>,
fn decode<__D>(decoder: &mut __D) -> Result<FeeSignatureVersion, DecodeError>where
__D: Decoder<Context = __Context>,
Attempt to decode this type with the given Decode.
impl Default for FeeSignatureVersion
impl Default for FeeSignatureVersion
fn default() -> FeeSignatureVersion
fn default() -> FeeSignatureVersion
Returns the “default value” for a type. Read more
impl Encode for FeeSignatureVersion
impl Encode for FeeSignatureVersion
impl PartialEq for FeeSignatureVersion
impl PartialEq for FeeSignatureVersion
impl Eq for FeeSignatureVersion
impl StructuralPartialEq for FeeSignatureVersion