Struct StateTransitionMinFees
pub struct StateTransitionMinFees {Show 14 fields
pub credit_transfer: u64,
pub credit_transfer_to_addresses: u64,
pub credit_withdrawal: u64,
pub identity_update: u64,
pub document_batch_sub_transition: u64,
pub contract_create: u64,
pub contract_update: u64,
pub masternode_vote: u64,
pub address_credit_withdrawal: u64,
pub address_funds_transfer_input_cost: u64,
pub address_funds_transfer_output_cost: u64,
pub identity_create_base_cost: u64,
pub identity_topup_base_cost: u64,
pub identity_key_in_creation_cost: u64,
}Fields
credit_transfer: u64credit_transfer_to_addresses: u64credit_withdrawal: u64identity_update: u64document_batch_sub_transition: u64contract_create: u64contract_update: u64masternode_vote: u64address_credit_withdrawal: u64address_funds_transfer_input_cost: u64address_funds_transfer_output_cost: u64identity_create_base_cost: u64identity_topup_base_cost: u64identity_key_in_creation_cost: u64Trait Implementations
impl<'__de, __Context> BorrowDecode<'__de, __Context> for StateTransitionMinFees
impl<'__de, __Context> BorrowDecode<'__de, __Context> for StateTransitionMinFees
fn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<StateTransitionMinFees, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<StateTransitionMinFees, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.
impl Clone for StateTransitionMinFees
impl Clone for StateTransitionMinFees
fn clone(&self) -> StateTransitionMinFees
fn clone(&self) -> StateTransitionMinFees
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for StateTransitionMinFees
impl Debug for StateTransitionMinFees
impl<__Context> Decode<__Context> for StateTransitionMinFees
impl<__Context> Decode<__Context> for StateTransitionMinFees
fn decode<__D>(decoder: &mut __D) -> Result<StateTransitionMinFees, DecodeError>where
__D: Decoder<Context = __Context>,
fn decode<__D>(decoder: &mut __D) -> Result<StateTransitionMinFees, DecodeError>where
__D: Decoder<Context = __Context>,
Attempt to decode this type with the given Decode.
impl Default for StateTransitionMinFees
impl Default for StateTransitionMinFees
fn default() -> StateTransitionMinFees
fn default() -> StateTransitionMinFees
Returns the “default value” for a type. Read more
impl Encode for StateTransitionMinFees
impl Encode for StateTransitionMinFees
impl From<StateTransitionMinFeesBeforeProtocolVersion11> for StateTransitionMinFees
impl From<StateTransitionMinFeesBeforeProtocolVersion11> for StateTransitionMinFees
fn from(
value: StateTransitionMinFeesBeforeProtocolVersion11,
) -> StateTransitionMinFees
fn from( value: StateTransitionMinFeesBeforeProtocolVersion11, ) -> StateTransitionMinFees
Converts to this type from the input type.
impl PartialEq for StateTransitionMinFees
impl PartialEq for StateTransitionMinFees
impl Eq for StateTransitionMinFees
impl StructuralPartialEq for StateTransitionMinFees