Struct StateTransitionMinFeesBeforeProtocolVersion11
pub struct StateTransitionMinFeesBeforeProtocolVersion11 {
pub credit_transfer: u64,
pub credit_withdrawal: u64,
pub identity_update: u64,
pub document_batch_sub_transition: u64,
pub contract_create: u64,
pub contract_update: u64,
pub masternode_vote: u64,
}Fields
credit_transfer: u64credit_withdrawal: u64identity_update: u64document_batch_sub_transition: u64contract_create: u64contract_update: u64masternode_vote: u64Trait Implementations
impl<'__de, __Context> BorrowDecode<'__de, __Context> for StateTransitionMinFeesBeforeProtocolVersion11
impl<'__de, __Context> BorrowDecode<'__de, __Context> for StateTransitionMinFeesBeforeProtocolVersion11
fn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<StateTransitionMinFeesBeforeProtocolVersion11, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<StateTransitionMinFeesBeforeProtocolVersion11, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.
impl Clone for StateTransitionMinFeesBeforeProtocolVersion11
impl Clone for StateTransitionMinFeesBeforeProtocolVersion11
fn clone(&self) -> StateTransitionMinFeesBeforeProtocolVersion11
fn clone(&self) -> StateTransitionMinFeesBeforeProtocolVersion11
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<__Context> Decode<__Context> for StateTransitionMinFeesBeforeProtocolVersion11
impl<__Context> Decode<__Context> for StateTransitionMinFeesBeforeProtocolVersion11
fn decode<__D>(
decoder: &mut __D,
) -> Result<StateTransitionMinFeesBeforeProtocolVersion11, DecodeError>where
__D: Decoder<Context = __Context>,
fn decode<__D>(
decoder: &mut __D,
) -> Result<StateTransitionMinFeesBeforeProtocolVersion11, DecodeError>where
__D: Decoder<Context = __Context>,
Attempt to decode this type with the given Decode.
impl Default for StateTransitionMinFeesBeforeProtocolVersion11
impl Default for StateTransitionMinFeesBeforeProtocolVersion11
fn default() -> StateTransitionMinFeesBeforeProtocolVersion11
fn default() -> StateTransitionMinFeesBeforeProtocolVersion11
Returns the “default value” for a type. Read more
impl From<StateTransitionMinFeesBeforeProtocolVersion11> for StateTransitionMinFees
impl From<StateTransitionMinFeesBeforeProtocolVersion11> for StateTransitionMinFees
fn from(
value: StateTransitionMinFeesBeforeProtocolVersion11,
) -> StateTransitionMinFees
fn from( value: StateTransitionMinFeesBeforeProtocolVersion11, ) -> StateTransitionMinFees
Converts to this type from the input type.
impl PartialEq for StateTransitionMinFeesBeforeProtocolVersion11
impl PartialEq for StateTransitionMinFeesBeforeProtocolVersion11
fn eq(&self, other: &StateTransitionMinFeesBeforeProtocolVersion11) -> bool
fn eq(&self, other: &StateTransitionMinFeesBeforeProtocolVersion11) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for StateTransitionMinFeesBeforeProtocolVersion11
impl StructuralPartialEq for StateTransitionMinFeesBeforeProtocolVersion11