pub struct ContenderWithSerializedDocumentV0 {
pub identity_id: Identifier,
pub serialized_document: Option<Vec<u8>>,
pub vote_tally: Option<u32>,
}Expand description
Represents a contender in the contested document vote poll. This is for internal use where the document is in serialized form
This struct holds the identity ID of the contender, the serialized document, and the vote tally.
Fields
identity_id: IdentifierThe identity ID of the contender.
serialized_document: Option<Vec<u8>>The serialized document associated with the contender.
vote_tally: Option<u32>The vote tally for the contender.
Implementations
Sourceimpl ContenderWithSerializedDocumentV0
impl ContenderWithSerializedDocumentV0
pub fn try_into_contender( self, document_type_ref: DocumentTypeRef<'_>, platform_version: &PlatformVersion, ) -> Result<ContenderV0, ProtocolError>
pub fn try_to_contender( &self, document_type_ref: DocumentTypeRef<'_>, platform_version: &PlatformVersion, ) -> Result<ContenderV0, ProtocolError>