pub struct FinalizedContender {
pub identity_id: Identifier,
pub document: Document,
pub serialized_document: Vec<u8>,
pub final_vote_tally: u32,
}Expand description
Represents a finalized contender in the contested document vote poll. This is for internal use where the document is in serialized form
This struct holds the identity ID of the contender, the document, and the vote tally.
Fields
identity_id: IdentifierThe identity ID of the contender.
document: DocumentThe document associated with the contender.
serialized_document: Vec<u8>The still serialized document
final_vote_tally: u32The vote tally for the contender.
Implementations
Sourceimpl FinalizedContender
impl FinalizedContender
Sourcepub fn try_from_contender_with_serialized_document(
value: FinalizedContenderWithSerializedDocument,
document_type: DocumentTypeRef<'_>,
platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>
pub fn try_from_contender_with_serialized_document( value: FinalizedContenderWithSerializedDocument, document_type: DocumentTypeRef<'_>, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
Try to get the finalized contender from a finalized contender with a serialized document