pub enum ResourceVoteChoice {
TowardsIdentity(Identifier),
Abstain,
Lock,
}Expand description
A resource votes is a votes determining what we should do with a contested resource. For example Alice and Bob both want the username “Malaka” Some would vote for Alice to get it by putting in her Identifier. Some would vote for Bob to get it by putting in Bob’s Identifier. Let’s say someone voted, but is now not quite sure of their votes, they can abstain. Lock is there to signal that the shared resource should be given to no one. In this case Malaka might have a bad connotation in Greek, hence some might votes to Lock the name.
Variants