pub trait ExtendedBlockInfoV0Getters {
// Required methods
fn basic_info(&self) -> &BlockInfo;
fn basic_info_mut(&mut self) -> &mut BlockInfo;
fn basic_info_owned(self) -> BlockInfo;
fn app_hash(&self) -> &[u8; 32];
fn quorum_hash(&self) -> &[u8; 32];
fn proposer_pro_tx_hash(&self) -> &[u8; 32];
fn block_id_hash(&self) -> &[u8; 32];
fn signature(&self) -> &[u8; 96];
fn round(&self) -> u32;
}Expand description
Trait for getting values from ExtendedBlockInfoV0
Required Methods
Sourcefn basic_info(&self) -> &BlockInfo
fn basic_info(&self) -> &BlockInfo
Returns a reference to the basic block info.
Sourcefn basic_info_mut(&mut self) -> &mut BlockInfo
fn basic_info_mut(&mut self) -> &mut BlockInfo
Returns a mutable reference to the basic block info.
Sourcefn basic_info_owned(self) -> BlockInfo
fn basic_info_owned(self) -> BlockInfo
Returns an owned copy of the basic block info.
Sourcefn quorum_hash(&self) -> &[u8; 32]
fn quorum_hash(&self) -> &[u8; 32]
Returns the quorum hash.
Sourcefn proposer_pro_tx_hash(&self) -> &[u8; 32]
fn proposer_pro_tx_hash(&self) -> &[u8; 32]
Proposer pro tx hash.
Sourcefn block_id_hash(&self) -> &[u8; 32]
fn block_id_hash(&self) -> &[u8; 32]
The block id hash