pub enum DocumentFactory {
V0(DocumentFactoryV0),
}Expand description
Document Factory
This module is responsible for creating instances of documents for a specific contract.
Versioning
The factory is versioned because the process of creating documents can change over time. Changes may be due to modifications in requirements, alterations in the document structure, or evolution in the dependencies of the document. Versioning allows for these changes to be tracked and managed effectively, providing flexibility to handle different versions of documents as needed.
Variants
V0(DocumentFactoryV0)
The version 0 implementation of the data contract factory.
Implementations
Sourceimpl DocumentFactory
impl DocumentFactory
Sourcepub fn new(protocol_version: u32) -> Result<Self, ProtocolError>
pub fn new(protocol_version: u32) -> Result<Self, ProtocolError>
Create a new document factory knowing versions
pub fn new_with_entropy_generator( protocol_version: u32, entropy_generator: Box<dyn EntropyGenerator>, ) -> Result<Self, ProtocolError>
pub fn create_document( &self, data_contract: &DataContract, owner_id: Identifier, document_type_name: String, data: Value, ) -> Result<Document, ProtocolError>
pub fn create_state_transition<'a>( &self, documents_iter: impl IntoIterator<Item = (DocumentTransitionActionType, Vec<(Document, DocumentTypeRef<'a>, Bytes32, Option<TokenPaymentInfo>)>)>, nonce_counter: &mut BTreeMap<(Identifier, Identifier), u64>, ) -> Result<BatchTransition, ProtocolError>