pub struct DocumentV0 {Show 14 fields
pub id: Identifier,
pub owner_id: Identifier,
pub properties: BTreeMap<String, Value>,
pub revision: Option<Revision>,
pub created_at: Option<TimestampMillis>,
pub updated_at: Option<TimestampMillis>,
pub transferred_at: Option<TimestampMillis>,
pub created_at_block_height: Option<BlockHeight>,
pub updated_at_block_height: Option<BlockHeight>,
pub transferred_at_block_height: Option<BlockHeight>,
pub created_at_core_block_height: Option<CoreBlockHeight>,
pub updated_at_core_block_height: Option<CoreBlockHeight>,
pub transferred_at_core_block_height: Option<CoreBlockHeight>,
pub creator_id: Option<Identifier>,
}Expand description
Documents contain the data that goes into data contracts.
Fields
id: IdentifierThe unique document ID.
owner_id: IdentifierThe ID of the document’s owner.
properties: BTreeMap<String, Value>The document’s properties (data).
revision: Option<Revision>The document revision, if the document is mutable.
created_at: Option<TimestampMillis>The time in milliseconds that the document was created, if it is set as required by the document type schema.
updated_at: Option<TimestampMillis>The time in milliseconds that the document was last updated, if it is set as required by the document type schema.
transferred_at: Option<TimestampMillis>The time in milliseconds that the document was last transferred, if it is set as required by the document type schema.
created_at_block_height: Option<BlockHeight>The block that the document was created, if it is set as required by the document type schema.
updated_at_block_height: Option<BlockHeight>The block that the document was last updated, if it is set as required by the document type schema.
transferred_at_block_height: Option<BlockHeight>The block that the document was last transferred to a new identity, if it is set as required by the document type schema.
created_at_core_block_height: Option<CoreBlockHeight>The core block that the document was created, if it is set as required by the document type schema.
updated_at_core_block_height: Option<CoreBlockHeight>The core block that the document was last updated, if it is set as required by the document type schema.
transferred_at_core_block_height: Option<CoreBlockHeight>The core block that the document was last transferred to a new identity, if it is set as required by the document type schema.
creator_id: Option<Identifier>The creator id.