DocumentV0Getters

Trait DocumentV0Getters 

pub trait DocumentV0Getters {
Show 19 methods // Required methods fn id(&self) -> Identifier; fn owner_id(&self) -> Identifier; fn properties(&self) -> &BTreeMap<String, Value>; fn properties_mut(&mut self) -> &mut BTreeMap<String, Value>; fn revision(&self) -> Option<Revision>; fn created_at(&self) -> Option<TimestampMillis>; fn updated_at(&self) -> Option<TimestampMillis>; fn transferred_at(&self) -> Option<TimestampMillis>; fn id_ref(&self) -> &Identifier; fn owner_id_ref(&self) -> &Identifier; fn properties_consumed(self) -> BTreeMap<String, Value>; fn created_at_block_height(&self) -> Option<u64>; fn updated_at_block_height(&self) -> Option<u64>; fn transferred_at_block_height(&self) -> Option<u64>; fn created_at_core_block_height(&self) -> Option<u32>; fn updated_at_core_block_height(&self) -> Option<u32>; fn transferred_at_core_block_height(&self) -> Option<u32>; fn creator_id(&self) -> Option<Identifier>; // Provided method fn get(&self, path: &str) -> Option<&Value> { ... }
}

Required Methods

fn id(&self) -> Identifier

Returns the unique document ID.

fn owner_id(&self) -> Identifier

Returns the ID of the document’s owner.

fn properties(&self) -> &BTreeMap<String, Value>

Returns the document’s properties (data).

fn properties_mut(&mut self) -> &mut BTreeMap<String, Value>

Returns a mutable reference to the document’s properties (data).

fn revision(&self) -> Option<Revision>

Returns the document revision.

fn created_at(&self) -> Option<TimestampMillis>

Returns the time in milliseconds that the document was created.

fn updated_at(&self) -> Option<TimestampMillis>

Returns the time in milliseconds that the document was last updated.

fn transferred_at(&self) -> Option<TimestampMillis>

Returns the time in milliseconds that the document was last transferred.

fn id_ref(&self) -> &Identifier

fn owner_id_ref(&self) -> &Identifier

fn properties_consumed(self) -> BTreeMap<String, Value>

fn created_at_block_height(&self) -> Option<u64>

fn updated_at_block_height(&self) -> Option<u64>

fn transferred_at_block_height(&self) -> Option<u64>

fn created_at_core_block_height(&self) -> Option<u32>

fn updated_at_core_block_height(&self) -> Option<u32>

fn transferred_at_core_block_height(&self) -> Option<u32>

fn creator_id(&self) -> Option<Identifier>

Provided Methods

fn get(&self, path: &str) -> Option<&Value>

Retrieves the field specified by the path. Returns None if the path is empty or if the field is not present.

Implementors