pub trait DocumentV0Getters {
Show 19 methods
// Required methods
fn id(&self) -> Identifier;
fn owner_id(&self) -> Identifier;
fn properties(&self) -> &BTreeMap<String, Value>;
fn properties_mut(&mut self) -> &mut BTreeMap<String, Value>;
fn revision(&self) -> Option<Revision>;
fn created_at(&self) -> Option<TimestampMillis>;
fn updated_at(&self) -> Option<TimestampMillis>;
fn transferred_at(&self) -> Option<TimestampMillis>;
fn id_ref(&self) -> &Identifier;
fn owner_id_ref(&self) -> &Identifier;
fn properties_consumed(self) -> BTreeMap<String, Value>;
fn created_at_block_height(&self) -> Option<u64>;
fn updated_at_block_height(&self) -> Option<u64>;
fn transferred_at_block_height(&self) -> Option<u64>;
fn created_at_core_block_height(&self) -> Option<u32>;
fn updated_at_core_block_height(&self) -> Option<u32>;
fn transferred_at_core_block_height(&self) -> Option<u32>;
fn creator_id(&self) -> Option<Identifier>;
// Provided method
fn get(&self, path: &str) -> Option<&Value> { ... }
}Required Methods
Sourcefn id(&self) -> Identifier
fn id(&self) -> Identifier
Returns the unique document ID.
Sourcefn owner_id(&self) -> Identifier
fn owner_id(&self) -> Identifier
Returns the ID of the document’s owner.
Sourcefn properties(&self) -> &BTreeMap<String, Value>
fn properties(&self) -> &BTreeMap<String, Value>
Returns the document’s properties (data).
Sourcefn properties_mut(&mut self) -> &mut BTreeMap<String, Value>
fn properties_mut(&mut self) -> &mut BTreeMap<String, Value>
Returns a mutable reference to the document’s properties (data).
Sourcefn created_at(&self) -> Option<TimestampMillis>
fn created_at(&self) -> Option<TimestampMillis>
Returns the time in milliseconds that the document was created.
Sourcefn updated_at(&self) -> Option<TimestampMillis>
fn updated_at(&self) -> Option<TimestampMillis>
Returns the time in milliseconds that the document was last updated.
Sourcefn transferred_at(&self) -> Option<TimestampMillis>
fn transferred_at(&self) -> Option<TimestampMillis>
Returns the time in milliseconds that the document was last transferred.