pub struct FeeResult {
pub storage_fee: Credits,
pub processing_fee: Credits,
pub fee_refunds: FeeRefunds,
pub removed_bytes_from_system: u32,
}Expand description
Fee Result
Fields
storage_fee: CreditsStorage fee
processing_fee: CreditsProcessing fee
fee_refunds: FeeRefundsCredits to refund to identities
removed_bytes_from_system: u32Removed bytes not needing to be refunded to identities
Implementations
Sourceimpl FeeResult
impl FeeResult
Sourcepub fn new_from_processing_fee(credits: Credits) -> Self
pub fn new_from_processing_fee(credits: Credits) -> Self
Convenience method to create a fee result from processing credits
Sourcepub fn apply_user_fee_increase(
&mut self,
add_fee_percentage_multiplier: UserFeeIncrease,
)
pub fn apply_user_fee_increase( &mut self, add_fee_percentage_multiplier: UserFeeIncrease, )
Apply a fee multiplier to a fee result
Sourcepub fn total_base_fee(&self) -> Credits
pub fn total_base_fee(&self) -> Credits
Convenience method to get total fee
Sourcepub fn into_balance_change(
self,
identity_id: Identifier,
) -> BalanceChangeForIdentity
pub fn into_balance_change( self, identity_id: Identifier, ) -> BalanceChangeForIdentity
Convenience method to get required removed balance
Sourcepub fn default_with_fees(storage_fee: Credits, processing_fee: Credits) -> Self
pub fn default_with_fees(storage_fee: Credits, processing_fee: Credits) -> Self
Creates a FeeResult instance with specified storage and processing fees
Sourcepub fn checked_add_assign(&mut self, rhs: Self) -> Result<(), ProtocolError>
pub fn checked_add_assign(&mut self, rhs: Self) -> Result<(), ProtocolError>
Adds and self assigns result between two Fee Results