pub struct CoreScript(/* private fields */);Implementations
Sourceimpl CoreScript
impl CoreScript
pub fn new(script: DashcoreScript) -> Self
pub fn to_string(&self, encoding: Encoding) -> String
pub fn from_string( encoded_value: &str, encoding: Encoding, ) -> Result<Self, ProtocolError>
pub fn from_bytes(bytes: Vec<u8>) -> Self
pub fn new_p2pkh(key_hash: [u8; 20]) -> Self
pub fn new_p2sh(script_hash: [u8; 20]) -> Self
pub fn random_p2sh(rng: &mut StdRng) -> Self
pub fn random_p2pkh(rng: &mut StdRng) -> Self
Methods from Deref<Target = DashcoreScript>
pub fn as_script(&self) -> &Script
pub fn as_script(&self) -> &Script
Returns a reference to unsized script.
pub fn to_p2sh(&self) -> ScriptBuf
pub fn to_p2sh(&self) -> ScriptBuf
Computes the P2SH output corresponding to this redeem script.
pub fn p2wpkh_script_code(&self) -> Option<ScriptBuf>
pub fn p2wpkh_script_code(&self) -> Option<ScriptBuf>
Returns the script code used for spending a P2WPKH output if this script is a script pubkey
for a P2WPKH output. The scriptCode is described in BIP143.
Methods from Deref<Target = Script>
pub fn as_mut_bytes(&mut self) -> &mut [u8] ⓘ
pub fn as_mut_bytes(&mut self) -> &mut [u8] ⓘ
Returns the script data as a mutable byte slice.
pub fn script_hash(&self) -> ScriptHash
pub fn script_hash(&self) -> ScriptHash
Returns 160-bit hash of the script.
pub fn wscript_hash(&self) -> WScriptHash
pub fn wscript_hash(&self) -> WScriptHash
Returns 256-bit hash of the script for P2WSH outputs.
pub fn tapscript_leaf_hash(&self) -> TapLeafHash
pub fn tapscript_leaf_hash(&self) -> TapLeafHash
Computes leaf hash of tapscript.
pub fn bytes(&self) -> Bytes<'_>
pub fn bytes(&self) -> Bytes<'_>
Returns an iterator over script bytes.
pub fn to_v0_p2wsh(&self) -> ScriptBuf
pub fn to_v0_p2wsh(&self) -> ScriptBuf
Computes the P2WSH output corresponding to this witnessScript (aka the “witness redeem script”).
pub fn to_v1_p2tr<C>(
&self,
secp: &Secp256k1<C>,
internal_key: XOnlyPublicKey,
) -> ScriptBufwhere
C: Verification,
pub fn to_v1_p2tr<C>(
&self,
secp: &Secp256k1<C>,
internal_key: XOnlyPublicKey,
) -> ScriptBufwhere
C: Verification,
Computes P2TR output with a given internal key and a single script spending path equal to the current script, assuming that the script is a Tapscript.
pub fn witness_version(&self) -> Option<WitnessVersion>
pub fn witness_version(&self) -> Option<WitnessVersion>
Returns witness version of the script, if any, assuming the script is a scriptPubkey.
pub fn is_p2pk(&self) -> bool
pub fn is_p2pk(&self) -> bool
Checks whether a script pubkey is a P2PK output.
You can obtain the public key, if its valid,
by calling p2pk_public_key()
pub fn p2pkh_public_key_hash_bytes(&self) -> Option<&[u8]>
pub fn p2pkh_public_key_hash_bytes(&self) -> Option<&[u8]>
Returns the public key hash if this script is P2PKH.
pub fn p2pk_public_key(&self) -> Option<PublicKey>
pub fn p2pk_public_key(&self) -> Option<PublicKey>
Returns the public key if this script is P2PK with a valid public key.
This may return None even when is_p2pk() returns true.
This happens when the public key is invalid (e.g. the point not being on the curve).
It also implies the script is unspendable.
pub fn p2pk_pubkey_bytes(&self) -> Option<&[u8]>
pub fn p2pk_pubkey_bytes(&self) -> Option<&[u8]>
Returns the bytes of the (possibly invalid) public key if this script is P2PK.
pub fn is_witness_program(&self) -> bool
pub fn is_witness_program(&self) -> bool
Checks whether a script pubkey is a Segregated Witness (segwit) program.
pub fn is_v0_p2wsh(&self) -> bool
pub fn is_v0_p2wsh(&self) -> bool
Checks whether a script pubkey is a P2WSH output.
pub fn is_v0_p2wpkh(&self) -> bool
pub fn is_v0_p2wpkh(&self) -> bool
Checks whether a script pubkey is a P2WPKH output.
pub fn v0_p2wpkh(&self) -> Option<&[u8; 20]>
pub fn v0_p2wpkh(&self) -> Option<&[u8; 20]>
Returns P2WPKH byte slice if this script is P2WPKH, otherwise None.
pub fn is_v1_p2tr(&self) -> bool
pub fn is_v1_p2tr(&self) -> bool
Checks whether a script pubkey is a P2TR output.
pub fn is_op_return(&self) -> bool
pub fn is_op_return(&self) -> bool
Check if this is an OP_RETURN output.
pub fn is_provably_unspendable(&self) -> bool
pub fn is_provably_unspendable(&self) -> bool
Checks whether a script can be proven to have no satisfying input.
pub fn dust_value(&self) -> Amount
pub fn dust_value(&self) -> Amount
Returns the minimum value an output with this script should have in order to be broadcastable on today’s Bitcoin network.
pub fn instructions(&self) -> Instructions<'_>
pub fn instructions(&self) -> Instructions<'_>
Iterates over the script instructions.
Each returned item is a nested enum covering opcodes, datapushes and errors.
At most one error will be returned and then the iterator will end. To instead iterate over
the script as sequence of bytes call the bytes method.
To force minimal pushes, use instructions_minimal.
pub fn instructions_minimal(&self) -> Instructions<'_>
pub fn instructions_minimal(&self) -> Instructions<'_>
Iterates over the script instructions while enforcing minimal pushes.
This is similar to instructions but an error is returned if a push
is not minimal.
pub fn instruction_indices(&self) -> InstructionIndices<'_>
pub fn instruction_indices(&self) -> InstructionIndices<'_>
Iterates over the script instructions and their indices.
Unless the script contains an error, the returned item consists of an index pointing to the position in the script where the instruction begins and the decoded instruction - either an opcode or data push.
To force minimal pushes, use [Self::instruction_indices_minimal].
pub fn instruction_indices_minimal(&self) -> InstructionIndices<'_>
pub fn instruction_indices_minimal(&self) -> InstructionIndices<'_>
Iterates over the script instructions and their indices while enforcing minimal pushes.
This is similar to instruction_indices but an error is
returned if a push is not minimal.
pub fn fmt_asm(&self, f: &mut dyn Write) -> Result<(), Error>
pub fn fmt_asm(&self, f: &mut dyn Write) -> Result<(), Error>
Writes the assembly decoding of the script to the formatter.
pub fn to_asm_string(&self) -> String
pub fn to_asm_string(&self) -> String
Returns the assembly decoding of the script.
pub fn to_hex_string(&self) -> String
pub fn to_hex_string(&self) -> String
Formats the script as lower-case hex.
This is a more convenient and performant way to write format!("{:x}", script).
For better performance you should generally prefer displaying the script but if String is
required (this is common in tests) this method is can be used.
pub fn first_opcode(&self) -> Option<All>
pub fn first_opcode(&self) -> Option<All>
Returns the first opcode of the script (if there is any).
pub fn last_opcode(&self) -> Option<All>
pub fn last_opcode(&self) -> Option<All>
Iterates the script to find the last opcode.
Returns None is the instruction is data push or if the script is empty.