pub enum Identity {
V0(IdentityV0),
}Expand description
The identity is not stored inside of drive, because of this, the serialization is mainly for transport, the serialization of the identity will include the version, so no passthrough or untagged is needed here
Variants
V0(IdentityV0)
Implementations
Sourceimpl Identity
impl Identity
pub fn default_versioned( platform_version: &PlatformVersion, ) -> Result<Identity, ProtocolError>
Sourcepub fn new_with_id_and_keys(
id: Identifier,
public_keys: BTreeMap<KeyID, IdentityPublicKey>,
platform_version: &PlatformVersion,
) -> Result<Identity, ProtocolError>
pub fn new_with_id_and_keys( id: Identifier, public_keys: BTreeMap<KeyID, IdentityPublicKey>, platform_version: &PlatformVersion, ) -> Result<Identity, ProtocolError>
Created a new identity based on asset locks and keys
Sourcepub fn new_with_input_addresses_and_keys(
inputs: &BTreeMap<PlatformAddress, (AddressNonce, Credits)>,
public_keys: BTreeMap<KeyID, IdentityPublicKey>,
platform_version: &PlatformVersion,
) -> Result<Identity, ProtocolError>
pub fn new_with_input_addresses_and_keys( inputs: &BTreeMap<PlatformAddress, (AddressNonce, Credits)>, public_keys: BTreeMap<KeyID, IdentityPublicKey>, platform_version: &PlatformVersion, ) -> Result<Identity, ProtocolError>
Create a new identity using input PlatformAddresses.
This function derives the identity ID from the provided input addresses.
Arguments
inputs- A map ofPlatformAddressto(AddressNonce, Credits). The identity id is derived from the addresses and nonces (credits are ignored for the id derivation). The nonces should represent state after creation of the identity (e.g. be incremented by 1).public_keys- A map of KeyID to IdentityPublicKey tuples representing the public keys for the identity.platform_version- The platform version to use for identity creation.
Returns
Result<Identity, ProtocolError>- Returns the newly created Identity or a ProtocolError if the operation fails.
Sourcepub fn into_partial_identity_info(self) -> PartialIdentity
pub fn into_partial_identity_info(self) -> PartialIdentity
Convenience method to get Partial Identity Info
Sourcepub fn into_partial_identity_info_no_balance(self) -> PartialIdentity
pub fn into_partial_identity_info_no_balance(self) -> PartialIdentity
Convenience method to get Partial Identity Info
Sourceimpl Identity
impl Identity
pub fn create_basic_identity( id: Identifier, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
Sourceimpl Identity
impl Identity
Sourcepub fn random_identity_with_rng(
key_count: KeyCount,
rng: &mut StdRng,
platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>
pub fn random_identity_with_rng( key_count: KeyCount, rng: &mut StdRng, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
Generates a random identity using the specified version and key count, with a provided RNG.
Arguments
version- An optional feature version for the identity. If not provided, the latest version will be used.key_count- The number of keys to generate for the identity.rng- A mutable reference to a random number generator to use for generating the identity.
Returns
A randomly generated identity of the specified version.
Panics
This function will panic if an unsupported version is provided.
Sourcepub fn random_identity_with_main_keys_with_private_key<I>(
key_count: KeyCount,
rng: &mut StdRng,
platform_version: &PlatformVersion,
) -> Result<(Self, I), ProtocolError>where
I: Default + IntoIterator<Item = (IdentityPublicKey, [u8; 32])> + Extend<(IdentityPublicKey, [u8; 32])>,
pub fn random_identity_with_main_keys_with_private_key<I>(
key_count: KeyCount,
rng: &mut StdRng,
platform_version: &PlatformVersion,
) -> Result<(Self, I), ProtocolError>where
I: Default + IntoIterator<Item = (IdentityPublicKey, [u8; 32])> + Extend<(IdentityPublicKey, [u8; 32])>,
Generates a random identity with main keys and their corresponding private keys, using the specified version and key count, with a provided RNG.
Arguments
version- An optional feature version for the identity. If not provided, the latest version will be used.key_count- The number of keys to generate for the identity.rng- A mutable reference to a random number generator to use for generating the identity.
Returns
A tuple containing the randomly generated identity and a collection of main keys with their corresponding private keys.
Panics
This function will panic if an unsupported version is provided.
Errors
This function may return a ProtocolError if an error occurs during identity generation.
Sourcepub fn random_identity(
key_count: KeyCount,
seed: Option<u64>,
platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>
pub fn random_identity( key_count: KeyCount, seed: Option<u64>, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
Generates a random identity using the specified version and key count, with an optional seed for reproducibility.
Arguments
version- An optional feature version for the identity. If not provided, the latest version will be used.key_count- The number of keys to generate for the identity.seed- An optional seed for reproducibility. If provided, the RNG will be seeded with this value.
Returns
A randomly generated identity of the specified version.
Panics
This function will panic if an unsupported version is provided.
Sourcepub fn random_identities(
count: u16,
key_count: KeyCount,
seed: Option<u64>,
platform_version: &PlatformVersion,
) -> Result<Vec<Self>, ProtocolError>
pub fn random_identities( count: u16, key_count: KeyCount, seed: Option<u64>, platform_version: &PlatformVersion, ) -> Result<Vec<Self>, ProtocolError>
Generates a specified number of random identities using the specified version and key count, with an optional seed for reproducibility.
Arguments
version- An optional feature version for the identity. If not provided, the latest version will be used.count- The number of identities to generate.key_count- The number of keys to generate for each identity.seed- An optional seed for reproducibility. If provided, the RNG will be seeded with this value.
Returns
A vector of randomly generated identities of the specified version.
Panics
This function will panic if an unsupported version is provided.
Sourcepub fn random_identities_with_rng(
count: u16,
key_count: KeyCount,
rng: &mut StdRng,
platform_version: &PlatformVersion,
) -> Result<Vec<Self>, ProtocolError>
pub fn random_identities_with_rng( count: u16, key_count: KeyCount, rng: &mut StdRng, platform_version: &PlatformVersion, ) -> Result<Vec<Self>, ProtocolError>
Generates a specified number of random identities using the specified version and key count, with a provided RNG.
Arguments
version- An optional feature version for the identity. If not provided, the latest version will be used.count- The number of identities to generate.key_count- The number of keys to generate for each identity.rng- A mutable reference to a random number generator to use for generating the identities.
Returns
A vector of randomly generated identities of the specified version.
Panics
This function will panic if an unsupported version is provided.
Sourcepub fn random_identities_with_private_keys_with_rng<I>(
count: u16,
key_count: KeyCount,
rng: &mut StdRng,
platform_version: &PlatformVersion,
) -> Result<(Vec<Self>, I), ProtocolError>where
I: Default + FromIterator<(IdentityPublicKey, [u8; 32])> + Extend<(IdentityPublicKey, [u8; 32])>,
pub fn random_identities_with_private_keys_with_rng<I>(
count: u16,
key_count: KeyCount,
rng: &mut StdRng,
platform_version: &PlatformVersion,
) -> Result<(Vec<Self>, I), ProtocolError>where
I: Default + FromIterator<(IdentityPublicKey, [u8; 32])> + Extend<(IdentityPublicKey, [u8; 32])>,
Generates a specified number of random identities with their corresponding private keys, using the specified version, key count, and a provided RNG.
Arguments
version- An optional feature version for the identity. If not provided, the latest version will be used.count- The number of identities to generate.key_count- The number of keys to generate for each identity.rng- A mutable reference to a random number generator to use for generating the identities.
Returns
A tuple containing a vector of randomly generated identities and a collection of main keys with their corresponding private keys.
Panics
This function will panic if an unsupported version is provided.
Errors
This function may return a ProtocolError if an error occurs during identity generation.