ContractBounds

Enum ContractBounds 

#[repr(u8)]
pub enum ContractBounds { SingleContract { id: Identifier, }, SingleContractDocumentType { id: Identifier, document_type_name: String, }, }
A contract bounds is the bounds that the key has influence on. For authentication keys the bounds mean that the keys can only be used to sign within the specified contract. For encryption decryption this tells clients to only use these keys for specific contracts.

Variants



SingleContract

this key can only be used within a specific contract

Fields



SingleContractDocumentType

this key can only be used within a specific contract and for a specific document type

Fields

document_type_name: String

Implementations

Source

impl ContractBounds

pub fn new_from_type( contract_bounds_type: u8, identifier: Vec<u8>, document_type: String, ) -> Result<Self, ProtocolError>

Creates a new contract bounds for the key

pub fn contract_bounds_type(&self) -> ContractBoundsType

Gets the contract bounds type

pub fn contract_bounds_type_from_str( str: &str, ) -> Result<ContractBoundsType, ProtocolError>

pub fn contract_bounds_type_string(&self) -> &str

Gets the contract bounds type

pub fn identifier(&self) -> &Identifier

Gets the identifier

pub fn document_type(&self) -> Option<&String>

Gets the document type