#[repr(u8)]pub enum ContractBounds {
SingleContract {
id: Identifier,
},
SingleContractDocumentType {
id: Identifier,
document_type_name: String,
},
}Expand description
A contract bounds is the bounds that the key has influence on. For authentication keys the bounds mean that the keys can only be used to sign within the specified contract. For encryption decryption this tells clients to only use these keys for specific contracts.
Variants
SingleContract
this key can only be used within a specific contract
Fields

id: IdentifierSingleContractDocumentType
this key can only be used within a specific contract and for a specific document type
Implementations
Sourceimpl ContractBounds
impl ContractBounds
Sourcepub fn new_from_type(
contract_bounds_type: u8,
identifier: Vec<u8>,
document_type: String,
) -> Result<Self, ProtocolError>
pub fn new_from_type( contract_bounds_type: u8, identifier: Vec<u8>, document_type: String, ) -> Result<Self, ProtocolError>
Creates a new contract bounds for the key
Sourcepub fn contract_bounds_type(&self) -> ContractBoundsType
pub fn contract_bounds_type(&self) -> ContractBoundsType
Gets the contract bounds type
pub fn contract_bounds_type_from_str( str: &str, ) -> Result<ContractBoundsType, ProtocolError>
Sourcepub fn contract_bounds_type_string(&self) -> &str
pub fn contract_bounds_type_string(&self) -> &str
Gets the contract bounds type
Sourcepub fn identifier(&self) -> &Identifier
pub fn identifier(&self) -> &Identifier
Gets the identifier
Sourcepub fn document_type(&self) -> Option<&String>
pub fn document_type(&self) -> Option<&String>
Gets the document type