#[repr(u8)]pub enum Purpose {
AUTHENTICATION = 0,
ENCRYPTION = 1,
DECRYPTION = 2,
TRANSFER = 3,
SYSTEM = 4,
VOTING = 5,
OWNER = 6,
}Variants
AUTHENTICATION = 0
at least one authentication key must be registered for all security levels
ENCRYPTION = 1
this key cannot be used for signing documents
DECRYPTION = 2
this key cannot be used for signing documents
TRANSFER = 3
this key is used to sign credit transfer and withdrawal state transitions this key can also be used by identities for claims and transfers of tokens
SYSTEM = 4
this key cannot be used for signing documents
VOTING = 5
this key cannot be used for signing documents
OWNER = 6
this key is used to prove ownership of a masternode or evonode
Implementations
Sourceimpl Purpose
impl Purpose
Sourcepub fn full_range() -> [Purpose; 6]
pub fn full_range() -> [Purpose; 6]
The full range of purposes
Sourcepub fn searchable_purposes() -> [Purpose; 3]
pub fn searchable_purposes() -> [Purpose; 3]
Just the authentication and withdraw purposes
Sourcepub fn encryption_decryption() -> [Purpose; 2]
pub fn encryption_decryption() -> [Purpose; 2]
Just the encryption and decryption purposes