pub fn token_purchase_from_shielded_pool_extra_sighash_data(
token_id: &[u8; 32],
token_count: u64,
total_agreed_price: u64,
platform_version: &PlatformVersion,
) -> Result<Vec<u8>, ProtocolError>Expand description
Extra sighash data of the token bundle of a TokenPurchaseFromShieldedPool: the state
transition type, the token id, the token count and the agreed price.