pub enum StateTransition {
Show 20 variants
DataContractCreate(DataContractCreateTransition),
DataContractUpdate(DataContractUpdateTransition),
Batch(BatchTransition),
IdentityCreate(IdentityCreateTransition),
IdentityTopUp(IdentityTopUpTransition),
IdentityCreditWithdrawal(IdentityCreditWithdrawalTransition),
IdentityUpdate(IdentityUpdateTransition),
IdentityCreditTransfer(IdentityCreditTransferTransition),
MasternodeVote(MasternodeVoteTransition),
IdentityCreditTransferToAddresses(IdentityCreditTransferToAddressesTransition),
IdentityCreateFromAddresses(IdentityCreateFromAddressesTransition),
IdentityTopUpFromAddresses(IdentityTopUpFromAddressesTransition),
AddressFundsTransfer(AddressFundsTransferTransition),
AddressFundingFromAssetLock(AddressFundingFromAssetLockTransition),
AddressCreditWithdrawal(AddressCreditWithdrawalTransition),
Shield(ShieldTransition),
ShieldedTransfer(ShieldedTransferTransition),
Unshield(UnshieldTransition),
ShieldFromAssetLock(ShieldFromAssetLockTransition),
ShieldedWithdrawal(ShieldedWithdrawalTransition),
}Variants
DataContractCreate(DataContractCreateTransition)
DataContractUpdate(DataContractUpdateTransition)
Batch(BatchTransition)
IdentityCreate(IdentityCreateTransition)
IdentityTopUp(IdentityTopUpTransition)
IdentityCreditWithdrawal(IdentityCreditWithdrawalTransition)
IdentityUpdate(IdentityUpdateTransition)
IdentityCreditTransfer(IdentityCreditTransferTransition)
MasternodeVote(MasternodeVoteTransition)
IdentityCreditTransferToAddresses(IdentityCreditTransferToAddressesTransition)
IdentityCreateFromAddresses(IdentityCreateFromAddressesTransition)
IdentityTopUpFromAddresses(IdentityTopUpFromAddressesTransition)
AddressFundsTransfer(AddressFundsTransferTransition)
AddressFundingFromAssetLock(AddressFundingFromAssetLockTransition)
AddressCreditWithdrawal(AddressCreditWithdrawalTransition)
Shield(ShieldTransition)
ShieldedTransfer(ShieldedTransferTransition)
Unshield(UnshieldTransition)
ShieldFromAssetLock(ShieldFromAssetLockTransition)
ShieldedWithdrawal(ShieldedWithdrawalTransition)
Implementations
Sourceimpl StateTransition
impl StateTransition
pub fn deserialize_many( raw_state_transitions: &[Vec<u8>], ) -> Result<Vec<Self>, ProtocolError>
Sourceimpl StateTransition
impl StateTransition
pub fn deserialize_from_bytes_in_version( bytes: &[u8], platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
pub fn active_version_range(&self) -> RangeInclusive<ProtocolVersion>
pub fn is_identity_signed(&self) -> bool
pub fn required_asset_lock_balance_for_processing_start( &self, platform_version: &PlatformVersion, ) -> Result<Credits, ProtocolError>
Sourcepub fn required_number_of_private_keys(&self) -> u16
pub fn required_number_of_private_keys(&self) -> u16
returns the number of private keys
Sourcepub fn user_fee_increase(&self) -> UserFeeIncrease
pub fn user_fee_increase(&self) -> UserFeeIncrease
returns the fee_increase additional percentage multiplier, it affects only processing costs
Sourcepub fn transaction_id(&self) -> Result<[u8; 32], ProtocolError>
pub fn transaction_id(&self) -> Result<[u8; 32], ProtocolError>
The transaction id is a single hash of the data with the signature
Sourcepub fn signature_public_key_id(&self) -> Option<KeyID>
pub fn signature_public_key_id(&self) -> Option<KeyID>
returns the signature as a byte-array
Sourcepub fn security_level_requirement(
&self,
purpose: Purpose,
) -> Option<Vec<SecurityLevel>>
pub fn security_level_requirement( &self, purpose: Purpose, ) -> Option<Vec<SecurityLevel>>
returns the key security level requirement for the state transition
Sourcepub fn purpose_requirement(&self) -> Option<Vec<Purpose>>
pub fn purpose_requirement(&self) -> Option<Vec<Purpose>>
returns the key purpose requirement for the state transition
Sourcepub fn owner_id(&self) -> Option<Identifier>
pub fn owner_id(&self) -> Option<Identifier>
returns the signature as a byte-array
Sourcepub fn inputs(
&self,
) -> Option<&BTreeMap<PlatformAddress, (AddressNonce, Credits)>>
pub fn inputs( &self, ) -> Option<&BTreeMap<PlatformAddress, (AddressNonce, Credits)>>
returns the signature as a byte-array
Sourcepub fn state_transition_type(&self) -> StateTransitionType
pub fn state_transition_type(&self) -> StateTransitionType
returns the state transition type
Sourcepub fn unique_identifiers(&self) -> Vec<String>
pub fn unique_identifiers(&self) -> Vec<String>
returns the unique identifiers for the state transition
Sourcepub fn set_signature(&mut self, signature: BinaryData) -> bool
pub fn set_signature(&mut self, signature: BinaryData) -> bool
set a new signature
Sourcepub fn set_user_fee_increase(&mut self, user_fee_increase: UserFeeIncrease)
pub fn set_user_fee_increase(&mut self, user_fee_increase: UserFeeIncrease)
set fee multiplier
Sourcepub fn set_signature_public_key_id(&mut self, public_key_id: KeyID)
pub fn set_signature_public_key_id(&mut self, public_key_id: KeyID)
set a new signature
pub fn sign_external<S: Signer<IdentityPublicKey>>( &mut self, identity_public_key: &IdentityPublicKey, signer: &S, get_data_contract_security_level_requirement: Option<impl Fn(Identifier, String) -> Result<SecurityLevel, ProtocolError>>, ) -> Result<(), ProtocolError>
pub fn sign_external_with_options<S: Signer<IdentityPublicKey>>( &mut self, identity_public_key: &IdentityPublicKey, signer: &S, get_data_contract_security_level_requirement: Option<impl Fn(Identifier, String) -> Result<SecurityLevel, ProtocolError>>, options: StateTransitionSigningOptions, ) -> Result<(), ProtocolError>
pub fn sign( &mut self, identity_public_key: &IdentityPublicKey, private_key: &[u8], bls: &impl BlsModule, ) -> Result<(), ProtocolError>
pub fn sign_with_options( &mut self, identity_public_key: &IdentityPublicKey, private_key: &[u8], bls: &impl BlsModule, options: StateTransitionSigningOptions, ) -> Result<(), ProtocolError>
Sourcepub fn sign_by_private_key(
&mut self,
private_key: &[u8],
key_type: KeyType,
bls: &impl BlsModule,
) -> Result<(), ProtocolError>
pub fn sign_by_private_key( &mut self, private_key: &[u8], key_type: KeyType, bls: &impl BlsModule, ) -> Result<(), ProtocolError>
Signs data with the private key
pub fn verify_identity_signed_signature( &self, public_key: &IdentityPublicKey, bls: &impl BlsModule, ) -> Result<(), ProtocolError>